# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: variant.proto
# Protobuf Python Version: 4.25.5
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\rvariant.proto\x12\x07variant\x1a\x1fgoogle/protobuf/timestamp.proto\"\xb1\x02\n\tAttribute\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x16\n\x0e\x61ttribute_type\x18\x03 \x01(\t\x12\x10\n\x08\x61rchived\x18\t \x01(\x08\x12\x30\n\nreferences\x18\x04 \x01(\x0b\x32\x1c.variant.AttributeReferences\x12.\n\ncreated_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\ncreated_by\x18\x06 \x01(\t\x12\x33\n\nupdated_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x00\x88\x01\x01\x12\x17\n\nupdated_by\x18\x08 \x01(\tH\x01\x88\x01\x01\x42\r\n\x0b_updated_atB\r\n\x0b_updated_by\"\xe7\x01\n\x07Variant\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x12\n\nis_default\x18\x05 \x01(\x08\x12.\n\ncreated_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\ncreated_by\x18\x07 \x01(\t\x12\x33\n\nupdated_at\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x00\x88\x01\x01\x12\x17\n\nupdated_by\x18\t \x01(\tH\x01\x88\x01\x01\x42\r\n\x0b_updated_atB\r\n\x0b_updated_by\".\n\x08Variants\x12\"\n\x08variants\x18\x01 \x03(\x0b\x32\x10.variant.Variant\"\xa2\x01\n\x11VariantManagement\x12\"\n\x08variants\x18\x01 \x03(\x0b\x32\x10.variant.Variant\x12&\n\nattributes\x18\x02 \x03(\x0b\x32\x12.variant.Attribute\x12\x41\n\x18variant_attribute_values\x18\x03 \x01(\x0b\x32\x1f.variant.VariantAttributeValues\"\x9e\x01\n\x16VariantAttributeValues\x12;\n\x06values\x18\x01 \x03(\x0b\x32+.variant.VariantAttributeValues.ValuesEntry\x1aG\n\x0bValuesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\'\n\x05value\x18\x02 \x01(\x0b\x32\x18.variant.AttributeValues:\x02\x38\x01\"v\n\x0f\x41ttributeValues\x12\x34\n\x06values\x18\x01 \x03(\x0b\x32$.variant.AttributeValues.ValuesEntry\x1a-\n\x0bValuesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"r\n\rVariantValues\x12\x32\n\x06values\x18\x01 \x03(\x0b\x32\".variant.VariantValues.ValuesEntry\x1a-\n\x0bValuesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xeb\x02\n\x13\x41ttributeReferences\x12\x38\n\x06topics\x18\x01 \x03(\x0b\x32(.variant.AttributeReferences.TopicsEntry\x12?\n\nflow_steps\x18\x02 \x03(\x0b\x32+.variant.AttributeReferences.FlowStepsEntry\x12\x44\n\rno_code_steps\x18\x03 \x03(\x0b\x32-.variant.AttributeReferences.NoCodeStepsEntry\x1a-\n\x0bTopicsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x08:\x02\x38\x01\x1a\x30\n\x0e\x46lowStepsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x08:\x02\x38\x01\x1a\x32\n\x10NoCodeStepsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x08:\x02\x38\x01\"e\n\x15Variant_CreateVariant\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x32\n\x10\x61ttribute_values\x18\x03 \x01(\x0b\x32\x18.variant.AttributeValues\"\x8d\x01\n\x15Variant_UpdateVariant\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\x04name\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x37\n\x10\x61ttribute_values\x18\x03 \x01(\x0b\x32\x18.variant.AttributeValuesH\x01\x88\x01\x01\x42\x07\n\x05_nameB\x13\n\x11_attribute_values\"#\n\x15Variant_DeleteVariant\x12\n\n\x02id\x18\x01 \x01(\t\"\x95\x01\n\x17Variant_CreateAttribute\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x30\n\nreferences\x18\x03 \x01(\x0b\x32\x1c.variant.AttributeReferences\x12.\n\x0evariant_values\x18\x04 \x01(\x0b\x32\x16.variant.VariantValues\"\xcf\x01\n\x17Variant_UpdateAttribute\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\x04name\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x35\n\nreferences\x18\x03 \x01(\x0b\x32\x1c.variant.AttributeReferencesH\x01\x88\x01\x01\x12\x33\n\x0evariant_values\x18\x04 \x01(\x0b\x32\x16.variant.VariantValuesH\x02\x88\x01\x01\x42\x07\n\x05_nameB\r\n\x0b_referencesB\x11\n\x0f_variant_values\"%\n\x17Variant_DeleteAttribute\x12\n\n\x02id\x18\x01 \x01(\t\"\'\n\x19Variant_SetDefaultVariant\x12\n\n\x02id\x18\x01 \x01(\t\"K\n\x1bVariant_ImportVariantForCsv\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x12\n\nis_default\x18\x03 \x01(\x08\"k\n\x1dVariant_ImportAttributeForCsv\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x30\n\nreferences\x18\x03 \x01(\x0b\x32\x1c.variant.AttributeReferences\"e\n*Variant_ImportVariantAttributeValuesForCsv\x12\x12\n\nvariant_id\x18\x01 \x01(\t\x12\x14\n\x0c\x61ttribute_id\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\t\"\x9f\x02\n\x16Variant_ImportVariants\x12\x36\n\x08variants\x18\x01 \x03(\x0b\x32$.variant.Variant_ImportVariantForCsv\x12:\n\nattributes\x18\x02 \x03(\x0b\x32&.variant.Variant_ImportAttributeForCsv\x12U\n\x18variant_attribute_values\x18\x03 \x03(\x0b\x32\x33.variant.Variant_ImportVariantAttributeValuesForCsv\x12\x1b\n\x13\x64\x65leted_variant_ids\x18\x04 \x03(\t\x12\x1d\n\x15\x64\x65leted_attribute_ids\x18\x05 \x03(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'variant_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_VARIANTATTRIBUTEVALUES_VALUESENTRY']._options = None
  _globals['_VARIANTATTRIBUTEVALUES_VALUESENTRY']._serialized_options = b'8\001'
  _globals['_ATTRIBUTEVALUES_VALUESENTRY']._options = None
  _globals['_ATTRIBUTEVALUES_VALUESENTRY']._serialized_options = b'8\001'
  _globals['_VARIANTVALUES_VALUESENTRY']._options = None
  _globals['_VARIANTVALUES_VALUESENTRY']._serialized_options = b'8\001'
  _globals['_ATTRIBUTEREFERENCES_TOPICSENTRY']._options = None
  _globals['_ATTRIBUTEREFERENCES_TOPICSENTRY']._serialized_options = b'8\001'
  _globals['_ATTRIBUTEREFERENCES_FLOWSTEPSENTRY']._options = None
  _globals['_ATTRIBUTEREFERENCES_FLOWSTEPSENTRY']._serialized_options = b'8\001'
  _globals['_ATTRIBUTEREFERENCES_NOCODESTEPSENTRY']._options = None
  _globals['_ATTRIBUTEREFERENCES_NOCODESTEPSENTRY']._serialized_options = b'8\001'
  _globals['_ATTRIBUTE']._serialized_start=60
  _globals['_ATTRIBUTE']._serialized_end=365
  _globals['_VARIANT']._serialized_start=368
  _globals['_VARIANT']._serialized_end=599
  _globals['_VARIANTS']._serialized_start=601
  _globals['_VARIANTS']._serialized_end=647
  _globals['_VARIANTMANAGEMENT']._serialized_start=650
  _globals['_VARIANTMANAGEMENT']._serialized_end=812
  _globals['_VARIANTATTRIBUTEVALUES']._serialized_start=815
  _globals['_VARIANTATTRIBUTEVALUES']._serialized_end=973
  _globals['_VARIANTATTRIBUTEVALUES_VALUESENTRY']._serialized_start=902
  _globals['_VARIANTATTRIBUTEVALUES_VALUESENTRY']._serialized_end=973
  _globals['_ATTRIBUTEVALUES']._serialized_start=975
  _globals['_ATTRIBUTEVALUES']._serialized_end=1093
  _globals['_ATTRIBUTEVALUES_VALUESENTRY']._serialized_start=1048
  _globals['_ATTRIBUTEVALUES_VALUESENTRY']._serialized_end=1093
  _globals['_VARIANTVALUES']._serialized_start=1095
  _globals['_VARIANTVALUES']._serialized_end=1209
  _globals['_VARIANTVALUES_VALUESENTRY']._serialized_start=1048
  _globals['_VARIANTVALUES_VALUESENTRY']._serialized_end=1093
  _globals['_ATTRIBUTEREFERENCES']._serialized_start=1212
  _globals['_ATTRIBUTEREFERENCES']._serialized_end=1575
  _globals['_ATTRIBUTEREFERENCES_TOPICSENTRY']._serialized_start=1428
  _globals['_ATTRIBUTEREFERENCES_TOPICSENTRY']._serialized_end=1473
  _globals['_ATTRIBUTEREFERENCES_FLOWSTEPSENTRY']._serialized_start=1475
  _globals['_ATTRIBUTEREFERENCES_FLOWSTEPSENTRY']._serialized_end=1523
  _globals['_ATTRIBUTEREFERENCES_NOCODESTEPSENTRY']._serialized_start=1525
  _globals['_ATTRIBUTEREFERENCES_NOCODESTEPSENTRY']._serialized_end=1575
  _globals['_VARIANT_CREATEVARIANT']._serialized_start=1577
  _globals['_VARIANT_CREATEVARIANT']._serialized_end=1678
  _globals['_VARIANT_UPDATEVARIANT']._serialized_start=1681
  _globals['_VARIANT_UPDATEVARIANT']._serialized_end=1822
  _globals['_VARIANT_DELETEVARIANT']._serialized_start=1824
  _globals['_VARIANT_DELETEVARIANT']._serialized_end=1859
  _globals['_VARIANT_CREATEATTRIBUTE']._serialized_start=1862
  _globals['_VARIANT_CREATEATTRIBUTE']._serialized_end=2011
  _globals['_VARIANT_UPDATEATTRIBUTE']._serialized_start=2014
  _globals['_VARIANT_UPDATEATTRIBUTE']._serialized_end=2221
  _globals['_VARIANT_DELETEATTRIBUTE']._serialized_start=2223
  _globals['_VARIANT_DELETEATTRIBUTE']._serialized_end=2260
  _globals['_VARIANT_SETDEFAULTVARIANT']._serialized_start=2262
  _globals['_VARIANT_SETDEFAULTVARIANT']._serialized_end=2301
  _globals['_VARIANT_IMPORTVARIANTFORCSV']._serialized_start=2303
  _globals['_VARIANT_IMPORTVARIANTFORCSV']._serialized_end=2378
  _globals['_VARIANT_IMPORTATTRIBUTEFORCSV']._serialized_start=2380
  _globals['_VARIANT_IMPORTATTRIBUTEFORCSV']._serialized_end=2487
  _globals['_VARIANT_IMPORTVARIANTATTRIBUTEVALUESFORCSV']._serialized_start=2489
  _globals['_VARIANT_IMPORTVARIANTATTRIBUTEVALUESFORCSV']._serialized_end=2590
  _globals['_VARIANT_IMPORTVARIANTS']._serialized_start=2593
  _globals['_VARIANT_IMPORTVARIANTS']._serialized_end=2880
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: pronunciations.proto
# Protobuf Python Version: 4.25.5
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14pronunciations.proto\x12\x0epronunciations\"\xed\x01\n\x07TTSRule\x12\n\n\x02id\x18\x01 \x01(\t\x12\r\n\x05regex\x18\x02 \x01(\t\x12\x13\n\x0breplacement\x18\x03 \x01(\t\x12\x16\n\x0e\x63\x61se_sensitive\x18\x04 \x01(\x08\x12\x12\n\ncreated_at\x18\x05 \x01(\t\x12\x12\n\ncreated_by\x18\x06 \x01(\t\x12\x12\n\nupdated_at\x18\x07 \x01(\t\x12\x12\n\nupdated_by\x18\x08 \x01(\t\x12\x15\n\rlanguage_code\x18\t \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\n \x01(\t\x12\x10\n\x08position\x18\x0b \x01(\x05\x12\x0c\n\x04name\x18\x0c \x01(\t\"A\n\x0ePronunciations\x12/\n\x0epronunciations\x18\x01 \x03(\x0b\x32\x17.pronunciations.TTSRule\"\xb8\x01\n\"Pronunciations_CreatePronunciation\x12\n\n\x02id\x18\x01 \x01(\t\x12\r\n\x05regex\x18\x02 \x01(\t\x12\x13\n\x0breplacement\x18\x03 \x01(\t\x12\x16\n\x0e\x63\x61se_sensitive\x18\x04 \x01(\x08\x12\x15\n\rlanguage_code\x18\x05 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x06 \x01(\t\x12\x10\n\x08position\x18\x07 \x01(\x05\x12\x0c\n\x04name\x18\x08 \x01(\t\"\xcc\x02\n\"Pronunciations_UpdatePronunciation\x12\x0f\n\x02id\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x12\n\x05regex\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x18\n\x0breplacement\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x1b\n\x0e\x63\x61se_sensitive\x18\x04 \x01(\x08H\x03\x88\x01\x01\x12\x1a\n\rlanguage_code\x18\x05 \x01(\tH\x04\x88\x01\x01\x12\x18\n\x0b\x64\x65scription\x18\x06 \x01(\tH\x05\x88\x01\x01\x12\x15\n\x08position\x18\x07 \x01(\x05H\x06\x88\x01\x01\x12\x11\n\x04name\x18\x08 \x01(\tH\x07\x88\x01\x01\x42\x05\n\x03_idB\x08\n\x06_regexB\x0e\n\x0c_replacementB\x11\n\x0f_case_sensitiveB\x10\n\x0e_language_codeB\x0e\n\x0c_descriptionB\x0b\n\t_positionB\x07\n\x05_name\"0\n\"Pronunciations_DeletePronunciation\x12\n\n\x02id\x18\x01 \x01(\t\"j\n$Pronunciations_ReorderPronunciations\x12\x42\n\rnew_positions\x18\x01 \x03(\x0b\x32+.pronunciations.PronunciationPositionUpdate\";\n\x1bPronunciationPositionUpdate\x12\n\n\x02id\x18\x01 \x01(\t\x12\x10\n\x08position\x18\x02 \x01(\x05\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'pronunciations_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_TTSRULE']._serialized_start=41
  _globals['_TTSRULE']._serialized_end=278
  _globals['_PRONUNCIATIONS']._serialized_start=280
  _globals['_PRONUNCIATIONS']._serialized_end=345
  _globals['_PRONUNCIATIONS_CREATEPRONUNCIATION']._serialized_start=348
  _globals['_PRONUNCIATIONS_CREATEPRONUNCIATION']._serialized_end=532
  _globals['_PRONUNCIATIONS_UPDATEPRONUNCIATION']._serialized_start=535
  _globals['_PRONUNCIATIONS_UPDATEPRONUNCIATION']._serialized_end=867
  _globals['_PRONUNCIATIONS_DELETEPRONUNCIATION']._serialized_start=869
  _globals['_PRONUNCIATIONS_DELETEPRONUNCIATION']._serialized_end=917
  _globals['_PRONUNCIATIONS_REORDERPRONUNCIATIONS']._serialized_start=919
  _globals['_PRONUNCIATIONS_REORDERPRONUNCIATIONS']._serialized_end=1025
  _globals['_PRONUNCIATIONPOSITIONUPDATE']._serialized_start=1027
  _globals['_PRONUNCIATIONPOSITIONUPDATE']._serialized_end=1086
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sms.proto
# Protobuf Python Version: 4.25.5
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\tsms.proto\x12\x03sms\x1a\x1fgoogle/protobuf/timestamp.proto\"H\n\x12SMSEnvPhoneNumbers\x12\x0f\n\x07sandbox\x18\x01 \x01(\t\x12\x13\n\x0bpre_release\x18\x02 \x01(\t\x12\x0c\n\x04live\x18\x03 \x01(\t\"\xdf\x02\n\x15SMSTemplateReferences\x12\x36\n\x06topics\x18\x01 \x03(\x0b\x32&.sms.SMSTemplateReferences.TopicsEntry\x12=\n\nflow_steps\x18\x02 \x03(\x0b\x32).sms.SMSTemplateReferences.FlowStepsEntry\x12<\n\tvariables\x18\x03 \x03(\x0b\x32).sms.SMSTemplateReferences.VariablesEntry\x1a-\n\x0bTopicsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x08:\x02\x38\x01\x1a\x30\n\x0e\x46lowStepsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x08:\x02\x38\x01\x1a\x30\n\x0eVariablesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x08:\x02\x38\x01\"*\n\x03SMS\x12#\n\ttemplates\x18\x01 \x03(\x0b\x32\x10.sms.SMSTemplate\"\xd9\x02\n\x0bSMSTemplate\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04text\x18\x03 \x01(\t\x12\x32\n\x11\x65nv_phone_numbers\x18\x04 \x01(\x0b\x32\x17.sms.SMSEnvPhoneNumbers\x12.\n\nreferences\x18\x05 \x01(\x0b\x32\x1a.sms.SMSTemplateReferences\x12.\n\ncreated_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\ncreated_by\x18\x07 \x01(\t\x12\x33\n\nupdated_at\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x00\x88\x01\x01\x12\x17\n\nupdated_by\x18\t \x01(\tH\x01\x88\x01\x01\x12\x0e\n\x06\x61\x63tive\x18\n \x01(\x08\x42\r\n\x0b_updated_atB\r\n\x0b_updated_by\"\xb0\x01\n\x12SMS_CreateTemplate\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04text\x18\x03 \x01(\t\x12\x32\n\x11\x65nv_phone_numbers\x18\x04 \x01(\x0b\x32\x17.sms.SMSEnvPhoneNumbers\x12.\n\nreferences\x18\x05 \x01(\x0b\x32\x1a.sms.SMSTemplateReferences\x12\x0e\n\x06\x61\x63tive\x18\x06 \x01(\x08\"\x82\x01\n\x18UpdateSMSEnvPhoneNumbers\x12\x14\n\x07sandbox\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x18\n\x0bpre_release\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x11\n\x04live\x18\x03 \x01(\tH\x02\x88\x01\x01\x42\n\n\x08_sandboxB\x0e\n\x0c_pre_releaseB\x07\n\x05_live\"\x91\x02\n\x12SMS_UpdateTemplate\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\x04name\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04text\x18\x03 \x01(\tH\x01\x88\x01\x01\x12=\n\x11\x65nv_phone_numbers\x18\x04 \x01(\x0b\x32\x1d.sms.UpdateSMSEnvPhoneNumbersH\x02\x88\x01\x01\x12\x33\n\nreferences\x18\x05 \x01(\x0b\x32\x1a.sms.SMSTemplateReferencesH\x03\x88\x01\x01\x12\x13\n\x06\x61\x63tive\x18\x06 \x01(\x08H\x04\x88\x01\x01\x42\x07\n\x05_nameB\x07\n\x05_textB\x14\n\x12_env_phone_numbersB\r\n\x0b_referencesB\t\n\x07_active\" \n\x12SMS_DeleteTemplate\x12\n\n\x02id\x18\x01 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sms_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_SMSTEMPLATEREFERENCES_TOPICSENTRY']._options = None
  _globals['_SMSTEMPLATEREFERENCES_TOPICSENTRY']._serialized_options = b'8\001'
  _globals['_SMSTEMPLATEREFERENCES_FLOWSTEPSENTRY']._options = None
  _globals['_SMSTEMPLATEREFERENCES_FLOWSTEPSENTRY']._serialized_options = b'8\001'
  _globals['_SMSTEMPLATEREFERENCES_VARIABLESENTRY']._options = None
  _globals['_SMSTEMPLATEREFERENCES_VARIABLESENTRY']._serialized_options = b'8\001'
  _globals['_SMSENVPHONENUMBERS']._serialized_start=51
  _globals['_SMSENVPHONENUMBERS']._serialized_end=123
  _globals['_SMSTEMPLATEREFERENCES']._serialized_start=126
  _globals['_SMSTEMPLATEREFERENCES']._serialized_end=477
  _globals['_SMSTEMPLATEREFERENCES_TOPICSENTRY']._serialized_start=332
  _globals['_SMSTEMPLATEREFERENCES_TOPICSENTRY']._serialized_end=377
  _globals['_SMSTEMPLATEREFERENCES_FLOWSTEPSENTRY']._serialized_start=379
  _globals['_SMSTEMPLATEREFERENCES_FLOWSTEPSENTRY']._serialized_end=427
  _globals['_SMSTEMPLATEREFERENCES_VARIABLESENTRY']._serialized_start=429
  _globals['_SMSTEMPLATEREFERENCES_VARIABLESENTRY']._serialized_end=477
  _globals['_SMS']._serialized_start=479
  _globals['_SMS']._serialized_end=521
  _globals['_SMSTEMPLATE']._serialized_start=524
  _globals['_SMSTEMPLATE']._serialized_end=869
  _globals['_SMS_CREATETEMPLATE']._serialized_start=872
  _globals['_SMS_CREATETEMPLATE']._serialized_end=1048
  _globals['_UPDATESMSENVPHONENUMBERS']._serialized_start=1051
  _globals['_UPDATESMSENVPHONENUMBERS']._serialized_end=1181
  _globals['_SMS_UPDATETEMPLATE']._serialized_start=1184
  _globals['_SMS_UPDATETEMPLATE']._serialized_end=1457
  _globals['_SMS_DELETETEMPLATE']._serialized_start=1459
  _globals['_SMS_DELETETEMPLATE']._serialized_end=1491
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bundle.proto
# Protobuf Python Version: 4.25.5
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from poly.handlers.protobuf import snapshot_pb2 as snapshot__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0c\x62undle.proto\x1a\x0esnapshot.proto\x1a\x1cgoogle/protobuf/struct.proto\"\x95\x01\n\x0bRagDatabase\x12\x17\n\x0f\x65mbedding_model\x18\x01 \x01(\t\x12\x37\n\x0e\x65mbeddings_map\x18\x02 \x03(\x0b\x32\x1f.RagDatabase.EmbeddingsMapEntry\x1a\x34\n\x12\x45mbeddingsMapEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"i\n\x15RealTimeConfiguration\x12\'\n\x06schema\x18\x01 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\'\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct\"\xdd\x01\n\x06\x42undle\x12$\n\x08snapshot\x18\x01 \x01(\x0b\x32\x12.snapshot.Snapshot\x12\x38\n\x11rt_configurations\x18\x02 \x03(\x0b\x32\x1d.Bundle.RtConfigurationsEntry\x12\"\n\x0crag_database\x18\x03 \x01(\x0b\x32\x0c.RagDatabase\x1aO\n\x15RtConfigurationsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12%\n\x05value\x18\x02 \x01(\x0b\x32\x16.RealTimeConfiguration:\x02\x38\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bundle_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_RAGDATABASE_EMBEDDINGSMAPENTRY']._options = None
  _globals['_RAGDATABASE_EMBEDDINGSMAPENTRY']._serialized_options = b'8\001'
  _globals['_BUNDLE_RTCONFIGURATIONSENTRY']._options = None
  _globals['_BUNDLE_RTCONFIGURATIONSENTRY']._serialized_options = b'8\001'
  _globals['_RAGDATABASE']._serialized_start=63
  _globals['_RAGDATABASE']._serialized_end=212
  _globals['_RAGDATABASE_EMBEDDINGSMAPENTRY']._serialized_start=160
  _globals['_RAGDATABASE_EMBEDDINGSMAPENTRY']._serialized_end=212
  _globals['_REALTIMECONFIGURATION']._serialized_start=214
  _globals['_REALTIMECONFIGURATION']._serialized_end=319
  _globals['_BUNDLE']._serialized_start=322
  _globals['_BUNDLE']._serialized_end=543
  _globals['_BUNDLE_RTCONFIGURATIONSENTRY']._serialized_start=464
  _globals['_BUNDLE_RTCONFIGURATIONSENTRY']._serialized_end=543
# @@protoc_insertion_point(module_scope)



from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ElevenLabsTtsConfig(_message.Message):
    __slots__ = ("model_id", "similarity_boost", "stability", "speed")
    MODEL_ID_FIELD_NUMBER: _ClassVar[int]
    SIMILARITY_BOOST_FIELD_NUMBER: _ClassVar[int]
    STABILITY_FIELD_NUMBER: _ClassVar[int]
    SPEED_FIELD_NUMBER: _ClassVar[int]
    model_id: str
    similarity_boost: float
    stability: float
    speed: float
    def __init__(self, model_id: _Optional[str] = ..., similarity_boost: _Optional[float] = ..., stability: _Optional[float] = ..., speed: _Optional[float] = ...) -> None: ...

class PlayHTTtsConfig(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class CartesiaTtsConfig(_message.Message):
    __slots__ = ("model_id", "speed", "emotion", "volume")
    MODEL_ID_FIELD_NUMBER: _ClassVar[int]
    SPEED_FIELD_NUMBER: _ClassVar[int]
    EMOTION_FIELD_NUMBER: _ClassVar[int]
    VOLUME_FIELD_NUMBER: _ClassVar[int]
    model_id: str
    speed: float
    emotion: str
    volume: float
    def __init__(self, model_id: _Optional[str] = ..., speed: _Optional[float] = ..., emotion: _Optional[str] = ..., volume: _Optional[float] = ...) -> None: ...

class HumeTtsConfig(_message.Message):
    __slots__ = ("model_id", "voice_description", "instant_mode", "provider")
    MODEL_ID_FIELD_NUMBER: _ClassVar[int]
    VOICE_DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    INSTANT_MODE_FIELD_NUMBER: _ClassVar[int]
    PROVIDER_FIELD_NUMBER: _ClassVar[int]
    model_id: str
    voice_description: str
    instant_mode: bool
    provider: str
    def __init__(self, model_id: _Optional[str] = ..., voice_description: _Optional[str] = ..., instant_mode: bool = ..., provider: _Optional[str] = ...) -> None: ...

class Voice(_message.Message):
    __slots__ = ("voice_id", "created_by", "created_at", "updated_by", "updated_at", "eleven_labs", "play_ht", "cartesia", "hume")
    VOICE_ID_FIELD_NUMBER: _ClassVar[int]
    CREATED_BY_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    UPDATED_BY_FIELD_NUMBER: _ClassVar[int]
    UPDATED_AT_FIELD_NUMBER: _ClassVar[int]
    ELEVEN_LABS_FIELD_NUMBER: _ClassVar[int]
    PLAY_HT_FIELD_NUMBER: _ClassVar[int]
    CARTESIA_FIELD_NUMBER: _ClassVar[int]
    HUME_FIELD_NUMBER: _ClassVar[int]
    voice_id: str
    created_by: str
    created_at: _timestamp_pb2.Timestamp
    updated_by: str
    updated_at: _timestamp_pb2.Timestamp
    eleven_labs: ElevenLabsTtsConfig
    play_ht: PlayHTTtsConfig
    cartesia: CartesiaTtsConfig
    hume: HumeTtsConfig
    def __init__(self, voice_id: _Optional[str] = ..., created_by: _Optional[str] = ..., created_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., updated_by: _Optional[str] = ..., updated_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., eleven_labs: _Optional[_Union[ElevenLabsTtsConfig, _Mapping]] = ..., play_ht: _Optional[_Union[PlayHTTtsConfig, _Mapping]] = ..., cartesia: _Optional[_Union[CartesiaTtsConfig, _Mapping]] = ..., hume: _Optional[_Union[HumeTtsConfig, _Mapping]] = ...) -> None: ...

class AgentVoice(_message.Message):
    __slots__ = ("voice_id", "probability", "updated_by", "updated_at", "language_code")
    VOICE_ID_FIELD_NUMBER: _ClassVar[int]
    PROBABILITY_FIELD_NUMBER: _ClassVar[int]
    UPDATED_BY_FIELD_NUMBER: _ClassVar[int]
    UPDATED_AT_FIELD_NUMBER: _ClassVar[int]
    LANGUAGE_CODE_FIELD_NUMBER: _ClassVar[int]
    voice_id: str
    probability: float
    updated_by: str
    updated_at: _timestamp_pb2.Timestamp
    language_code: str
    def __init__(self, voice_id: _Optional[str] = ..., probability: _Optional[float] = ..., updated_by: _Optional[str] = ..., updated_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., language_code: _Optional[str] = ...) -> None: ...

class DisclaimerVoice(_message.Message):
    __slots__ = ("voice_id", "updated_by", "updated_at", "language_code")
    VOICE_ID_FIELD_NUMBER: _ClassVar[int]
    UPDATED_BY_FIELD_NUMBER: _ClassVar[int]
    UPDATED_AT_FIELD_NUMBER: _ClassVar[int]
    LANGUAGE_CODE_FIELD_NUMBER: _ClassVar[int]
    voice_id: str
    updated_by: str
    updated_at: _timestamp_pb2.Timestamp
    language_code: str
    def __init__(self, voice_id: _Optional[str] = ..., updated_by: _Optional[str] = ..., updated_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., language_code: _Optional[str] = ...) -> None: ...

class FavoriteVoice(_message.Message):
    __slots__ = ("voice_id", "account_id", "created_by", "created_at", "updated_by", "updated_at")
    VOICE_ID_FIELD_NUMBER: _ClassVar[int]
    ACCOUNT_ID_FIELD_NUMBER: _ClassVar[int]
    CREATED_BY_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    UPDATED_BY_FIELD_NUMBER: _ClassVar[int]
    UPDATED_AT_FIELD_NUMBER: _ClassVar[int]
    voice_id: str
    account_id: str
    created_by: str
    created_at: _timestamp_pb2.Timestamp
    updated_by: str
    updated_at: _timestamp_pb2.Timestamp
    def __init__(self, voice_id: _Optional[str] = ..., account_id: _Optional[str] = ..., created_by: _Optional[str] = ..., created_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., updated_by: _Optional[str] = ..., updated_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class Voices(_message.Message):
    __slots__ = ("agent_voices", "disclaimer_voices", "agent_voice_settings", "disclaimer_voice_settings", "favorite_voices")
    AGENT_VOICES_FIELD_NUMBER: _ClassVar[int]
    DISCLAIMER_VOICES_FIELD_NUMBER: _ClassVar[int]
    AGENT_VOICE_SETTINGS_FIELD_NUMBER: _ClassVar[int]
    DISCLAIMER_VOICE_SETTINGS_FIELD_NUMBER: _ClassVar[int]
    FAVORITE_VOICES_FIELD_NUMBER: _ClassVar[int]
    agent_voices: _containers.RepeatedCompositeFieldContainer[AgentVoice]
    disclaimer_voices: _containers.RepeatedCompositeFieldContainer[DisclaimerVoice]
    agent_voice_settings: _containers.RepeatedCompositeFieldContainer[Voice]
    disclaimer_voice_settings: _containers.RepeatedCompositeFieldContainer[Voice]
    favorite_voices: _containers.RepeatedCompositeFieldContainer[FavoriteVoice]
    def __init__(self, agent_voices: _Optional[_Iterable[_Union[AgentVoice, _Mapping]]] = ..., disclaimer_voices: _Optional[_Iterable[_Union[DisclaimerVoice, _Mapping]]] = ..., agent_voice_settings: _Optional[_Iterable[_Union[Voice, _Mapping]]] = ..., disclaimer_voice_settings: _Optional[_Iterable[_Union[Voice, _Mapping]]] = ..., favorite_voices: _Optional[_Iterable[_Union[FavoriteVoice, _Mapping]]] = ...) -> None: ...

class Voice_AddAgentVoice(_message.Message):
    __slots__ = ("voice_id", "probability", "language_code")
    VOICE_ID_FIELD_NUMBER: _ClassVar[int]
    PROBABILITY_FIELD_NUMBER: _ClassVar[int]
    LANGUAGE_CODE_FIELD_NUMBER: _ClassVar[int]
    voice_id: str
    probability: float
    language_code: str
    def __init__(self, voice_id: _Optional[str] = ..., probability: _Optional[float] = ..., language_code: _Optional[str] = ...) -> None: ...

class Voice_DeleteAgentVoice(_message.Message):
    __slots__ = ("voice_id",)
    VOICE_ID_FIELD_NUMBER: _ClassVar[int]
    voice_id: str
    def __init__(self, voice_id: _Optional[str] = ...) -> None: ...

class Voice_UpdateAgentVoice(_message.Message):
    __slots__ = ("voice_id", "probability", "new_voice_id")
    VOICE_ID_FIELD_NUMBER: _ClassVar[int]
    PROBABILITY_FIELD_NUMBER: _ClassVar[int]
    NEW_VOICE_ID_FIELD_NUMBER: _ClassVar[int]
    voice_id: str
    probability: float
    new_voice_id: str
    def __init__(self, voice_id: _Optional[str] = ..., probability: _Optional[float] = ..., new_voice_id: _Optional[str] = ...) -> None: ...

class Voice_CreateAgentVoiceSettings(_message.Message):
    __slots__ = ("voice_id", "eleven_labs", "play_ht", "cartesia", "hume")
    VOICE_ID_FIELD_NUMBER: _ClassVar[int]
    ELEVEN_LABS_FIELD_NUMBER: _ClassVar[int]
    PLAY_HT_FIELD_NUMBER: _ClassVar[int]
    CARTESIA_FIELD_NUMBER: _ClassVar[int]
    HUME_FIELD_NUMBER: _ClassVar[int]
    voice_id: str
    eleven_labs: ElevenLabsTtsConfig
    play_ht: PlayHTTtsConfig
    cartesia: CartesiaTtsConfig
    hume: HumeTtsConfig
    def __init__(self, voice_id: _Optional[str] = ..., eleven_labs: _Optional[_Union[ElevenLabsTtsConfig, _Mapping]] = ..., play_ht: _Optional[_Union[PlayHTTtsConfig, _Mapping]] = ..., cartesia: _Optional[_Union[CartesiaTtsConfig, _Mapping]] = ..., hume: _Optional[_Union[HumeTtsConfig, _Mapping]] = ...) -> None: ...

class Voice_UpdateAgentVoiceSettings(_message.Message):
    __slots__ = ("voice_id", "eleven_labs", "play_ht", "cartesia", "hume")
    VOICE_ID_FIELD_NUMBER: _ClassVar[int]
    ELEVEN_LABS_FIELD_NUMBER: _ClassVar[int]
    PLAY_HT_FIELD_NUMBER: _ClassVar[int]
    CARTESIA_FIELD_NUMBER: _ClassVar[int]
    HUME_FIELD_NUMBER: _ClassVar[int]
    voice_id: str
    eleven_labs: ElevenLabsTtsConfig
    play_ht: PlayHTTtsConfig
    cartesia: CartesiaTtsConfig
    hume: HumeTtsConfig
    def __init__(self, voice_id: _Optional[str] = ..., eleven_labs: _Optional[_Union[ElevenLabsTtsConfig, _Mapping]] = ..., play_ht: _Optional[_Union[PlayHTTtsConfig, _Mapping]] = ..., cartesia: _Optional[_Union[CartesiaTtsConfig, _Mapping]] = ..., hume: _Optional[_Union[HumeTtsConfig, _Mapping]] = ...) -> None: ...

class Voice_UpdateDisclaimerVoice(_message.Message):
    __slots__ = ("voice_id", "language_code")
    VOICE_ID_FIELD_NUMBER: _ClassVar[int]
    LANGUAGE_CODE_FIELD_NUMBER: _ClassVar[int]
    voice_id: str
    language_code: str
    def __init__(self, voice_id: _Optional[str] = ..., language_code: _Optional[str] = ...) -> None: ...

class Voice_CreateDisclaimerVoiceSettings(_message.Message):
    __slots__ = ("voice_id", "eleven_labs", "play_ht", "cartesia", "hume")
    VOICE_ID_FIELD_NUMBER: _ClassVar[int]
    ELEVEN_LABS_FIELD_NUMBER: _ClassVar[int]
    PLAY_HT_FIELD_NUMBER: _ClassVar[int]
    CARTESIA_FIELD_NUMBER: _ClassVar[int]
    HUME_FIELD_NUMBER: _ClassVar[int]
    voice_id: str
    eleven_labs: ElevenLabsTtsConfig
    play_ht: PlayHTTtsConfig
    cartesia: CartesiaTtsConfig
    hume: HumeTtsConfig
    def __init__(self, voice_id: _Optional[str] = ..., eleven_labs: _Optional[_Union[ElevenLabsTtsConfig, _Mapping]] = ..., play_ht: _Optional[_Union[PlayHTTtsConfig, _Mapping]] = ..., cartesia: _Optional[_Union[CartesiaTtsConfig, _Mapping]] = ..., hume: _Optional[_Union[HumeTtsConfig, _Mapping]] = ...) -> None: ...

class Voice_UpdateDisclaimerVoiceSettings(_message.Message):
    __slots__ = ("voice_id", "eleven_labs", "play_ht", "cartesia", "hume")
    VOICE_ID_FIELD_NUMBER: _ClassVar[int]
    ELEVEN_LABS_FIELD_NUMBER: _ClassVar[int]
    PLAY_HT_FIELD_NUMBER: _ClassVar[int]
    CARTESIA_FIELD_NUMBER: _ClassVar[int]
    HUME_FIELD_NUMBER: _ClassVar[int]
    voice_id: str
    eleven_labs: ElevenLabsTtsConfig
    play_ht: PlayHTTtsConfig
    cartesia: CartesiaTtsConfig
    hume: HumeTtsConfig
    def __init__(self, voice_id: _Optional[str] = ..., eleven_labs: _Optional[_Union[ElevenLabsTtsConfig, _Mapping]] = ..., play_ht: _Optional[_Union[PlayHTTtsConfig, _Mapping]] = ..., cartesia: _Optional[_Union[CartesiaTtsConfig, _Mapping]] = ..., hume: _Optional[_Union[HumeTtsConfig, _Mapping]] = ...) -> None: ...

class Voice_AddFavoriteVoice(_message.Message):
    __slots__ = ("voice_id", "account_id")
    VOICE_ID_FIELD_NUMBER: _ClassVar[int]
    ACCOUNT_ID_FIELD_NUMBER: _ClassVar[int]
    voice_id: str
    account_id: str
    def __init__(self, voice_id: _Optional[str] = ..., account_id: _Optional[str] = ...) -> None: ...

class Voice_RemoveFavoriteVoice(_message.Message):
    __slots__ = ("voice_id", "account_id")
    VOICE_ID_FIELD_NUMBER: _ClassVar[int]
    ACCOUNT_ID_FIELD_NUMBER: _ClassVar[int]
    voice_id: str
    account_id: str
    def __init__(self, voice_id: _Optional[str] = ..., account_id: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tts_settings.proto
# Protobuf Python Version: 4.25.5
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12tts_settings.proto\x12\x0ctts_settings\x1a\x1fgoogle/protobuf/timestamp.proto\"\x90\x01\n\x0bTTSSettings\x12\x15\n\rlanguage_code\x18\x01 \x01(\t\x12\x17\n\nupdated_by\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x33\n\nupdated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x01\x88\x01\x01\x42\r\n\x0b_updated_byB\r\n\x0b_updated_at\"6\n\x1dTTSSettings_UpdateTTSSettings\x12\x15\n\rlanguage_code\x18\x01 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tts_settings_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_TTSSETTINGS']._serialized_start=70
  _globals['_TTSSETTINGS']._serialized_end=214
  _globals['_TTSSETTINGS_UPDATETTSSETTINGS']._serialized_start=216
  _globals['_TTSSETTINGS_UPDATETTSSETTINGS']._serialized_end=270
# @@protoc_insertion_point(module_scope)



from agent_v2 import agent_pb2 as _agent_pb2
from agent_v3.genai.proto.integrations import integrations_pb2 as _integrations_pb2
from google.protobuf import duration_pb2 as _duration_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf import struct_pb2 as _struct_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CoreArtifact(_message.Message):
    __slots__ = ("name", "last_updated", "functions_deployment", "conversation_limits", "voice", "asr", "model", "assistant_config", "knowledge_base", "functions", "start_function", "handoffs", "voice_tuning_settings", "sms_templates", "flows", "intro_message", "stop_keywords", "variants", "variant_attributes", "end_function", "deployed_voices", "entities", "api_integrations", "variables", "disclaimers", "agent_voices", "multilingual_agent_settings", "multilingual_translations", "channels", "integrations")
    NAME_FIELD_NUMBER: _ClassVar[int]
    LAST_UPDATED_FIELD_NUMBER: _ClassVar[int]
    FUNCTIONS_DEPLOYMENT_FIELD_NUMBER: _ClassVar[int]
    CONVERSATION_LIMITS_FIELD_NUMBER: _ClassVar[int]
    VOICE_FIELD_NUMBER: _ClassVar[int]
    ASR_FIELD_NUMBER: _ClassVar[int]
    MODEL_FIELD_NUMBER: _ClassVar[int]
    ASSISTANT_CONFIG_FIELD_NUMBER: _ClassVar[int]
    KNOWLEDGE_BASE_FIELD_NUMBER: _ClassVar[int]
    FUNCTIONS_FIELD_NUMBER: _ClassVar[int]
    START_FUNCTION_FIELD_NUMBER: _ClassVar[int]
    HANDOFFS_FIELD_NUMBER: _ClassVar[int]
    VOICE_TUNING_SETTINGS_FIELD_NUMBER: _ClassVar[int]
    SMS_TEMPLATES_FIELD_NUMBER: _ClassVar[int]
    FLOWS_FIELD_NUMBER: _ClassVar[int]
    INTRO_MESSAGE_FIELD_NUMBER: _ClassVar[int]
    STOP_KEYWORDS_FIELD_NUMBER: _ClassVar[int]
    VARIANTS_FIELD_NUMBER: _ClassVar[int]
    VARIANT_ATTRIBUTES_FIELD_NUMBER: _ClassVar[int]
    END_FUNCTION_FIELD_NUMBER: _ClassVar[int]
    DEPLOYED_VOICES_FIELD_NUMBER: _ClassVar[int]
    ENTITIES_FIELD_NUMBER: _ClassVar[int]
    API_INTEGRATIONS_FIELD_NUMBER: _ClassVar[int]
    VARIABLES_FIELD_NUMBER: _ClassVar[int]
    DISCLAIMERS_FIELD_NUMBER: _ClassVar[int]
    AGENT_VOICES_FIELD_NUMBER: _ClassVar[int]
    MULTILINGUAL_AGENT_SETTINGS_FIELD_NUMBER: _ClassVar[int]
    MULTILINGUAL_TRANSLATIONS_FIELD_NUMBER: _ClassVar[int]
    CHANNELS_FIELD_NUMBER: _ClassVar[int]
    INTEGRATIONS_FIELD_NUMBER: _ClassVar[int]
    name: str
    last_updated: _timestamp_pb2.Timestamp
    functions_deployment: FunctionsDeployment
    conversation_limits: ConversationLimits
    voice: Voice
    asr: Asr
    model: Model
    assistant_config: AssistantConfig
    knowledge_base: KnowledgeBase
    functions: _containers.RepeatedCompositeFieldContainer[Function]
    start_function: Function
    handoffs: _containers.RepeatedCompositeFieldContainer[Handoff]
    voice_tuning_settings: _containers.RepeatedCompositeFieldContainer[VoiceTuningSettings]
    sms_templates: _containers.RepeatedCompositeFieldContainer[SMSTemplate]
    flows: Flows
    intro_message: IntroMessage
    stop_keywords: _containers.RepeatedCompositeFieldContainer[StopKeywords]
    variants: _containers.RepeatedCompositeFieldContainer[Variant]
    variant_attributes: _containers.RepeatedCompositeFieldContainer[VariantAttribute]
    end_function: Function
    deployed_voices: DeployedVoices
    entities: Entities
    api_integrations: ApiIntegrations
    variables: Variables
    disclaimers: _containers.RepeatedCompositeFieldContainer[IntroMessage]
    agent_voices: _containers.RepeatedCompositeFieldContainer[DeployedVoices]
    multilingual_agent_settings: MultilingualAgentSettings
    multilingual_translations: MultilingualTranslations
    channels: Channels
    integrations: _integrations_pb2.Integrations
    def __init__(self, name: _Optional[str] = ..., last_updated: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., functions_deployment: _Optional[_Union[FunctionsDeployment, _Mapping]] = ..., conversation_limits: _Optional[_Union[ConversationLimits, _Mapping]] = ..., voice: _Optional[_Union[Voice, _Mapping]] = ..., asr: _Optional[_Union[Asr, _Mapping]] = ..., model: _Optional[_Union[Model, _Mapping]] = ..., assistant_config: _Optional[_Union[AssistantConfig, _Mapping]] = ..., knowledge_base: _Optional[_Union[KnowledgeBase, _Mapping]] = ..., functions: _Optional[_Iterable[_Union[Function, _Mapping]]] = ..., start_function: _Optional[_Union[Function, _Mapping]] = ..., handoffs: _Optional[_Iterable[_Union[Handoff, _Mapping]]] = ..., voice_tuning_settings: _Optional[_Iterable[_Union[VoiceTuningSettings, _Mapping]]] = ..., sms_templates: _Optional[_Iterable[_Union[SMSTemplate, _Mapping]]] = ..., flows: _Optional[_Union[Flows, _Mapping]] = ..., intro_message: _Optional[_Union[IntroMessage, _Mapping]] = ..., stop_keywords: _Optional[_Iterable[_Union[StopKeywords, _Mapping]]] = ..., variants: _Optional[_Iterable[_Union[Variant, _Mapping]]] = ..., variant_attributes: _Optional[_Iterable[_Union[VariantAttribute, _Mapping]]] = ..., end_function: _Optional[_Union[Function, _Mapping]] = ..., deployed_voices: _Optional[_Union[DeployedVoices, _Mapping]] = ..., entities: _Optional[_Union[Entities, _Mapping]] = ..., api_integrations: _Optional[_Union[ApiIntegrations, _Mapping]] = ..., variables: _Optional[_Union[Variables, _Mapping]] = ..., disclaimers: _Optional[_Iterable[_Union[IntroMessage, _Mapping]]] = ..., agent_voices: _Optional[_Iterable[_Union[DeployedVoices, _Mapping]]] = ..., multilingual_agent_settings: _Optional[_Union[MultilingualAgentSettings, _Mapping]] = ..., multilingual_translations: _Optional[_Union[MultilingualTranslations, _Mapping]] = ..., channels: _Optional[_Union[Channels, _Mapping]] = ..., integrations: _Optional[_Union[_integrations_pb2.Integrations, _Mapping]] = ...) -> None: ...

class VoiceWithProbability(_message.Message):
    __slots__ = ("voice", "probability", "voice_tuning_settings")
    VOICE_FIELD_NUMBER: _ClassVar[int]
    PROBABILITY_FIELD_NUMBER: _ClassVar[int]
    VOICE_TUNING_SETTINGS_FIELD_NUMBER: _ClassVar[int]
    voice: Voice
    probability: float
    voice_tuning_settings: VoiceTuningSettings
    def __init__(self, voice: _Optional[_Union[Voice, _Mapping]] = ..., probability: _Optional[float] = ..., voice_tuning_settings: _Optional[_Union[VoiceTuningSettings, _Mapping]] = ...) -> None: ...

class Entities(_message.Message):
    __slots__ = ("entities",)
    ENTITIES_FIELD_NUMBER: _ClassVar[int]
    entities: _containers.RepeatedCompositeFieldContainer[Entity]
    def __init__(self, entities: _Optional[_Iterable[_Union[Entity, _Mapping]]] = ...) -> None: ...

class Entity(_message.Message):
    __slots__ = ("name", "description", "type", "id", "alphanumeric_config", "number_config", "date_config", "time_config", "phone_number_config", "name_config", "address_config", "free_text_config", "multiple_options_config")
    NAME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    ALPHANUMERIC_CONFIG_FIELD_NUMBER: _ClassVar[int]
    NUMBER_CONFIG_FIELD_NUMBER: _ClassVar[int]
    DATE_CONFIG_FIELD_NUMBER: _ClassVar[int]
    TIME_CONFIG_FIELD_NUMBER: _ClassVar[int]
    PHONE_NUMBER_CONFIG_FIELD_NUMBER: _ClassVar[int]
    NAME_CONFIG_FIELD_NUMBER: _ClassVar[int]
    ADDRESS_CONFIG_FIELD_NUMBER: _ClassVar[int]
    FREE_TEXT_CONFIG_FIELD_NUMBER: _ClassVar[int]
    MULTIPLE_OPTIONS_CONFIG_FIELD_NUMBER: _ClassVar[int]
    name: str
    description: str
    type: str
    id: str
    alphanumeric_config: AlphanumericEntityConfig
    number_config: NumberEntityConfig
    date_config: DateEntityConfig
    time_config: TimeEntityConfig
    phone_number_config: PhoneNumberEntityConfig
    name_config: NameEntityConfig
    address_config: AddressEntityConfig
    free_text_config: FreeTextEntityConfig
    multiple_options_config: MultipleOptionsEntityConfig
    def __init__(self, name: _Optional[str] = ..., description: _Optional[str] = ..., type: _Optional[str] = ..., id: _Optional[str] = ..., alphanumeric_config: _Optional[_Union[AlphanumericEntityConfig, _Mapping]] = ..., number_config: _Optional[_Union[NumberEntityConfig, _Mapping]] = ..., date_config: _Optional[_Union[DateEntityConfig, _Mapping]] = ..., time_config: _Optional[_Union[TimeEntityConfig, _Mapping]] = ..., phone_number_config: _Optional[_Union[PhoneNumberEntityConfig, _Mapping]] = ..., name_config: _Optional[_Union[NameEntityConfig, _Mapping]] = ..., address_config: _Optional[_Union[AddressEntityConfig, _Mapping]] = ..., free_text_config: _Optional[_Union[FreeTextEntityConfig, _Mapping]] = ..., multiple_options_config: _Optional[_Union[MultipleOptionsEntityConfig, _Mapping]] = ...) -> None: ...

class Variables(_message.Message):
    __slots__ = ("variables",)
    VARIABLES_FIELD_NUMBER: _ClassVar[int]
    variables: _containers.RepeatedCompositeFieldContainer[Variable]
    def __init__(self, variables: _Optional[_Iterable[_Union[Variable, _Mapping]]] = ...) -> None: ...

class Variable(_message.Message):
    __slots__ = ("id", "name", "created_by", "created_at", "updated_by", "updated_at")
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    CREATED_BY_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    UPDATED_BY_FIELD_NUMBER: _ClassVar[int]
    UPDATED_AT_FIELD_NUMBER: _ClassVar[int]
    id: str
    name: str
    created_by: str
    created_at: _timestamp_pb2.Timestamp
    updated_by: str
    updated_at: _timestamp_pb2.Timestamp
    def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ..., created_by: _Optional[str] = ..., created_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., updated_by: _Optional[str] = ..., updated_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class NumberEntityConfig(_message.Message):
    __slots__ = ("min", "max", "numeric_type")
    MIN_FIELD_NUMBER: _ClassVar[int]
    MAX_FIELD_NUMBER: _ClassVar[int]
    NUMERIC_TYPE_FIELD_NUMBER: _ClassVar[int]
    min: float
    max: float
    numeric_type: str
    def __init__(self, min: _Optional[float] = ..., max: _Optional[float] = ..., numeric_type: _Optional[str] = ...) -> None: ...

class AlphanumericEntityConfig(_message.Message):
    __slots__ = ("regex",)
    REGEX_FIELD_NUMBER: _ClassVar[int]
    regex: str
    def __init__(self, regex: _Optional[str] = ...) -> None: ...

class MultipleOptionsEntityConfig(_message.Message):
    __slots__ = ("options",)
    OPTIONS_FIELD_NUMBER: _ClassVar[int]
    options: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, options: _Optional[_Iterable[str]] = ...) -> None: ...

class DateEntityConfig(_message.Message):
    __slots__ = ("day_first", "start_date", "end_date")
    DAY_FIRST_FIELD_NUMBER: _ClassVar[int]
    START_DATE_FIELD_NUMBER: _ClassVar[int]
    END_DATE_FIELD_NUMBER: _ClassVar[int]
    day_first: bool
    start_date: str
    end_date: str
    def __init__(self, day_first: bool = ..., start_date: _Optional[str] = ..., end_date: _Optional[str] = ...) -> None: ...

class PhoneNumberEntityConfig(_message.Message):
    __slots__ = ("country_codes",)
    COUNTRY_CODES_FIELD_NUMBER: _ClassVar[int]
    country_codes: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, country_codes: _Optional[_Iterable[str]] = ...) -> None: ...

class TimeEntityConfig(_message.Message):
    __slots__ = ("start_time", "end_time")
    START_TIME_FIELD_NUMBER: _ClassVar[int]
    END_TIME_FIELD_NUMBER: _ClassVar[int]
    start_time: str
    end_time: str
    def __init__(self, start_time: _Optional[str] = ..., end_time: _Optional[str] = ...) -> None: ...

class NameEntityConfig(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class AddressEntityConfig(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class FreeTextEntityConfig(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class DeployedVoices(_message.Message):
    __slots__ = ("voices_with_proba", "language_code")
    VOICES_WITH_PROBA_FIELD_NUMBER: _ClassVar[int]
    LANGUAGE_CODE_FIELD_NUMBER: _ClassVar[int]
    voices_with_proba: _containers.RepeatedCompositeFieldContainer[VoiceWithProbability]
    language_code: str
    def __init__(self, voices_with_proba: _Optional[_Iterable[_Union[VoiceWithProbability, _Mapping]]] = ..., language_code: _Optional[str] = ...) -> None: ...

class ConversationLimits(_message.Message):
    __slots__ = ("call_duration_limit", "chat_turn_limit")
    CALL_DURATION_LIMIT_FIELD_NUMBER: _ClassVar[int]
    CHAT_TURN_LIMIT_FIELD_NUMBER: _ClassVar[int]
    call_duration_limit: int
    chat_turn_limit: int
    def __init__(self, call_duration_limit: _Optional[int] = ..., chat_turn_limit: _Optional[int] = ...) -> None: ...

class Voice(_message.Message):
    __slots__ = ("provider_voice_id", "provider", "config")
    PROVIDER_VOICE_ID_FIELD_NUMBER: _ClassVar[int]
    PROVIDER_FIELD_NUMBER: _ClassVar[int]
    CONFIG_FIELD_NUMBER: _ClassVar[int]
    provider_voice_id: str
    provider: str
    config: _struct_pb2.Struct
    def __init__(self, provider_voice_id: _Optional[str] = ..., provider: _Optional[str] = ..., config: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ...) -> None: ...

class Asr(_message.Message):
    __slots__ = ("provider_id", "model_id", "language", "config")
    PROVIDER_ID_FIELD_NUMBER: _ClassVar[int]
    MODEL_ID_FIELD_NUMBER: _ClassVar[int]
    LANGUAGE_FIELD_NUMBER: _ClassVar[int]
    CONFIG_FIELD_NUMBER: _ClassVar[int]
    provider_id: str
    model_id: str
    language: str
    config: _struct_pb2.Struct
    def __init__(self, provider_id: _Optional[str] = ..., model_id: _Optional[str] = ..., language: _Optional[str] = ..., config: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ...) -> None: ...

class TTSRule(_message.Message):
    __slots__ = ("regex", "replacement", "case_sensitive", "language_code")
    REGEX_FIELD_NUMBER: _ClassVar[int]
    REPLACEMENT_FIELD_NUMBER: _ClassVar[int]
    CASE_SENSITIVE_FIELD_NUMBER: _ClassVar[int]
    LANGUAGE_CODE_FIELD_NUMBER: _ClassVar[int]
    regex: str
    replacement: str
    case_sensitive: bool
    language_code: str
    def __init__(self, regex: _Optional[str] = ..., replacement: _Optional[str] = ..., case_sensitive: bool = ..., language_code: _Optional[str] = ...) -> None: ...

class Model(_message.Message):
    __slots__ = ("provider_model_id", "config")
    PROVIDER_MODEL_ID_FIELD_NUMBER: _ClassVar[int]
    CONFIG_FIELD_NUMBER: _ClassVar[int]
    provider_model_id: str
    config: _struct_pb2.Struct
    def __init__(self, provider_model_id: _Optional[str] = ..., config: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ...) -> None: ...

class AssistantConfig(_message.Message):
    __slots__ = ("updated_at", "updated_by", "default_handoff_id", "model_id", "voice_id", "config", "asr_id", "tts_rules", "content_filter", "barge_in_config", "latency_config", "asr_keyphrases", "asr_corrections", "languages")
    UPDATED_AT_FIELD_NUMBER: _ClassVar[int]
    UPDATED_BY_FIELD_NUMBER: _ClassVar[int]
    DEFAULT_HANDOFF_ID_FIELD_NUMBER: _ClassVar[int]
    MODEL_ID_FIELD_NUMBER: _ClassVar[int]
    VOICE_ID_FIELD_NUMBER: _ClassVar[int]
    CONFIG_FIELD_NUMBER: _ClassVar[int]
    ASR_ID_FIELD_NUMBER: _ClassVar[int]
    TTS_RULES_FIELD_NUMBER: _ClassVar[int]
    CONTENT_FILTER_FIELD_NUMBER: _ClassVar[int]
    BARGE_IN_CONFIG_FIELD_NUMBER: _ClassVar[int]
    LATENCY_CONFIG_FIELD_NUMBER: _ClassVar[int]
    ASR_KEYPHRASES_FIELD_NUMBER: _ClassVar[int]
    ASR_CORRECTIONS_FIELD_NUMBER: _ClassVar[int]
    LANGUAGES_FIELD_NUMBER: _ClassVar[int]
    updated_at: _timestamp_pb2.Timestamp
    updated_by: str
    default_handoff_id: str
    model_id: str
    voice_id: str
    config: _struct_pb2.Struct
    asr_id: str
    tts_rules: _containers.RepeatedCompositeFieldContainer[TTSRule]
    content_filter: ContentFilter
    barge_in_config: BargeInConfig
    latency_config: LatencyConfig
    asr_keyphrases: _containers.RepeatedCompositeFieldContainer[AsrKeyphrase]
    asr_corrections: _containers.RepeatedCompositeFieldContainer[AsrCorrection]
    languages: Languages
    def __init__(self, updated_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., updated_by: _Optional[str] = ..., default_handoff_id: _Optional[str] = ..., model_id: _Optional[str] = ..., voice_id: _Optional[str] = ..., config: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ..., asr_id: _Optional[str] = ..., tts_rules: _Optional[_Iterable[_Union[TTSRule, _Mapping]]] = ..., content_filter: _Optional[_Union[ContentFilter, _Mapping]] = ..., barge_in_config: _Optional[_Union[BargeInConfig, _Mapping]] = ..., latency_config: _Optional[_Union[LatencyConfig, _Mapping]] = ..., asr_keyphrases: _Optional[_Iterable[_Union[AsrKeyphrase, _Mapping]]] = ..., asr_corrections: _Optional[_Iterable[_Union[AsrCorrection, _Mapping]]] = ..., languages: _Optional[_Union[Languages, _Mapping]] = ...) -> None: ...

class Rules(_message.Message):
    __slots__ = ("behaviour", "system_prompt", "functions", "handoffs", "sms_templates", "variant_attributes")
    BEHAVIOUR_FIELD_NUMBER: _ClassVar[int]
    SYSTEM_PROMPT_FIELD_NUMBER: _ClassVar[int]
    FUNCTIONS_FIELD_NUMBER: _ClassVar[int]
    HANDOFFS_FIELD_NUMBER: _ClassVar[int]
    SMS_TEMPLATES_FIELD_NUMBER: _ClassVar[int]
    VARIANT_ATTRIBUTES_FIELD_NUMBER: _ClassVar[int]
    behaviour: str
    system_prompt: str
    functions: _containers.RepeatedScalarFieldContainer[str]
    handoffs: _containers.RepeatedScalarFieldContainer[str]
    sms_templates: _containers.RepeatedScalarFieldContainer[str]
    variant_attributes: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, behaviour: _Optional[str] = ..., system_prompt: _Optional[str] = ..., functions: _Optional[_Iterable[str]] = ..., handoffs: _Optional[_Iterable[str]] = ..., sms_templates: _Optional[_Iterable[str]] = ..., variant_attributes: _Optional[_Iterable[str]] = ...) -> None: ...

class Personality(_message.Message):
    __slots__ = ("adjectives", "custom", "adjectives_dict")
    ADJECTIVES_FIELD_NUMBER: _ClassVar[int]
    CUSTOM_FIELD_NUMBER: _ClassVar[int]
    ADJECTIVES_DICT_FIELD_NUMBER: _ClassVar[int]
    adjectives: _containers.RepeatedScalarFieldContainer[str]
    custom: str
    adjectives_dict: _struct_pb2.Struct
    def __init__(self, adjectives: _Optional[_Iterable[str]] = ..., custom: _Optional[str] = ..., adjectives_dict: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ...) -> None: ...

class Role(_message.Message):
    __slots__ = ("value", "additional_info", "custom")
    VALUE_FIELD_NUMBER: _ClassVar[int]
    ADDITIONAL_INFO_FIELD_NUMBER: _ClassVar[int]
    CUSTOM_FIELD_NUMBER: _ClassVar[int]
    value: str
    additional_info: str
    custom: str
    def __init__(self, value: _Optional[str] = ..., additional_info: _Optional[str] = ..., custom: _Optional[str] = ...) -> None: ...

class KnowledgeBaseMetadata(_message.Message):
    __slots__ = ("rules", "personality", "role")
    RULES_FIELD_NUMBER: _ClassVar[int]
    PERSONALITY_FIELD_NUMBER: _ClassVar[int]
    ROLE_FIELD_NUMBER: _ClassVar[int]
    rules: Rules
    personality: Personality
    role: Role
    def __init__(self, rules: _Optional[_Union[Rules, _Mapping]] = ..., personality: _Optional[_Union[Personality, _Mapping]] = ..., role: _Optional[_Union[Role, _Mapping]] = ...) -> None: ...

class KnowledgeBase(_message.Message):
    __slots__ = ("updated_at", "updated_by", "welcome_message", "knowledge_base", "additional_context", "system_prompt")
    UPDATED_AT_FIELD_NUMBER: _ClassVar[int]
    UPDATED_BY_FIELD_NUMBER: _ClassVar[int]
    WELCOME_MESSAGE_FIELD_NUMBER: _ClassVar[int]
    KNOWLEDGE_BASE_FIELD_NUMBER: _ClassVar[int]
    ADDITIONAL_CONTEXT_FIELD_NUMBER: _ClassVar[int]
    SYSTEM_PROMPT_FIELD_NUMBER: _ClassVar[int]
    updated_at: _timestamp_pb2.Timestamp
    updated_by: str
    welcome_message: str
    knowledge_base: KnowledgeBaseMetadata
    additional_context: _struct_pb2.Struct
    system_prompt: str
    def __init__(self, updated_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., updated_by: _Optional[str] = ..., welcome_message: _Optional[str] = ..., knowledge_base: _Optional[_Union[KnowledgeBaseMetadata, _Mapping]] = ..., additional_context: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ..., system_prompt: _Optional[str] = ...) -> None: ...

class FunctionParameter(_message.Message):
    __slots__ = ("name", "type", "description")
    NAME_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    name: str
    type: str
    description: str
    def __init__(self, name: _Optional[str] = ..., type: _Optional[str] = ..., description: _Optional[str] = ...) -> None: ...

class DelayResponse(_message.Message):
    __slots__ = ("message", "duration")
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    DURATION_FIELD_NUMBER: _ClassVar[int]
    message: str
    duration: int
    def __init__(self, message: _Optional[str] = ..., duration: _Optional[int] = ...) -> None: ...

class LatencyControl(_message.Message):
    __slots__ = ("initial_delay", "interval", "delay_responses")
    INITIAL_DELAY_FIELD_NUMBER: _ClassVar[int]
    INTERVAL_FIELD_NUMBER: _ClassVar[int]
    DELAY_RESPONSES_FIELD_NUMBER: _ClassVar[int]
    initial_delay: int
    interval: int
    delay_responses: _containers.RepeatedCompositeFieldContainer[DelayResponse]
    def __init__(self, initial_delay: _Optional[int] = ..., interval: _Optional[int] = ..., delay_responses: _Optional[_Iterable[_Union[DelayResponse, _Mapping]]] = ...) -> None: ...

class Function(_message.Message):
    __slots__ = ("id", "function_id", "name", "description", "parameters", "associated_flow", "latency_control", "prefix_path")
    ID_FIELD_NUMBER: _ClassVar[int]
    FUNCTION_ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    PARAMETERS_FIELD_NUMBER: _ClassVar[int]
    ASSOCIATED_FLOW_FIELD_NUMBER: _ClassVar[int]
    LATENCY_CONTROL_FIELD_NUMBER: _ClassVar[int]
    PREFIX_PATH_FIELD_NUMBER: _ClassVar[int]
    id: str
    function_id: str
    name: str
    description: str
    parameters: _containers.RepeatedCompositeFieldContainer[FunctionParameter]
    associated_flow: str
    latency_control: LatencyControl
    prefix_path: str
    def __init__(self, id: _Optional[str] = ..., function_id: _Optional[str] = ..., name: _Optional[str] = ..., description: _Optional[str] = ..., parameters: _Optional[_Iterable[_Union[FunctionParameter, _Mapping]]] = ..., associated_flow: _Optional[str] = ..., latency_control: _Optional[_Union[LatencyControl, _Mapping]] = ..., prefix_path: _Optional[str] = ...) -> None: ...

class FunctionsDeployment(_message.Message):
    __slots__ = ("id", "deployment_version")
    ID_FIELD_NUMBER: _ClassVar[int]
    DEPLOYMENT_VERSION_FIELD_NUMBER: _ClassVar[int]
    id: str
    deployment_version: str
    def __init__(self, id: _Optional[str] = ..., deployment_version: _Optional[str] = ...) -> None: ...

class Handoff(_message.Message):
    __slots__ = ("id", "name", "created_at", "created_by", "updated_at", "updated_by", "description", "extension", "invite", "refer", "bye")
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    CREATED_BY_FIELD_NUMBER: _ClassVar[int]
    UPDATED_AT_FIELD_NUMBER: _ClassVar[int]
    UPDATED_BY_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    EXTENSION_FIELD_NUMBER: _ClassVar[int]
    INVITE_FIELD_NUMBER: _ClassVar[int]
    REFER_FIELD_NUMBER: _ClassVar[int]
    BYE_FIELD_NUMBER: _ClassVar[int]
    id: str
    name: str
    created_at: _timestamp_pb2.Timestamp
    created_by: str
    updated_at: _timestamp_pb2.Timestamp
    updated_by: str
    description: str
    extension: str
    invite: _agent_pb2.InviteHandoff
    refer: _agent_pb2.ReferHandoff
    bye: _agent_pb2.ByeHandoff
    def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ..., created_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., created_by: _Optional[str] = ..., updated_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., updated_by: _Optional[str] = ..., description: _Optional[str] = ..., extension: _Optional[str] = ..., invite: _Optional[_Union[_agent_pb2.InviteHandoff, _Mapping]] = ..., refer: _Optional[_Union[_agent_pb2.ReferHandoff, _Mapping]] = ..., bye: _Optional[_Union[_agent_pb2.ByeHandoff, _Mapping]] = ...) -> None: ...

class VoiceTuningSettings(_message.Message):
    __slots__ = ("genai_project_id", "voice_config_id", "settings", "created_by", "created_at", "updated_by", "updated_at")
    GENAI_PROJECT_ID_FIELD_NUMBER: _ClassVar[int]
    VOICE_CONFIG_ID_FIELD_NUMBER: _ClassVar[int]
    SETTINGS_FIELD_NUMBER: _ClassVar[int]
    CREATED_BY_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    UPDATED_BY_FIELD_NUMBER: _ClassVar[int]
    UPDATED_AT_FIELD_NUMBER: _ClassVar[int]
    genai_project_id: str
    voice_config_id: str
    settings: _struct_pb2.Struct
    created_by: str
    created_at: _timestamp_pb2.Timestamp
    updated_by: str
    updated_at: _timestamp_pb2.Timestamp
    def __init__(self, genai_project_id: _Optional[str] = ..., voice_config_id: _Optional[str] = ..., settings: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ..., created_by: _Optional[str] = ..., created_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., updated_by: _Optional[str] = ..., updated_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class SMSEnvNumbers(_message.Message):
    __slots__ = ("sandbox", "pre_release", "live")
    SANDBOX_FIELD_NUMBER: _ClassVar[int]
    PRE_RELEASE_FIELD_NUMBER: _ClassVar[int]
    LIVE_FIELD_NUMBER: _ClassVar[int]
    sandbox: str
    pre_release: str
    live: str
    def __init__(self, sandbox: _Optional[str] = ..., pre_release: _Optional[str] = ..., live: _Optional[str] = ...) -> None: ...

class SMSTemplate(_message.Message):
    __slots__ = ("id", "template_name", "template_text", "created_at", "created_by", "updated_at", "updated_by", "sms_numbers")
    ID_FIELD_NUMBER: _ClassVar[int]
    TEMPLATE_NAME_FIELD_NUMBER: _ClassVar[int]
    TEMPLATE_TEXT_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    CREATED_BY_FIELD_NUMBER: _ClassVar[int]
    UPDATED_AT_FIELD_NUMBER: _ClassVar[int]
    UPDATED_BY_FIELD_NUMBER: _ClassVar[int]
    SMS_NUMBERS_FIELD_NUMBER: _ClassVar[int]
    id: str
    template_name: str
    template_text: str
    created_at: _timestamp_pb2.Timestamp
    created_by: str
    updated_at: _timestamp_pb2.Timestamp
    updated_by: str
    sms_numbers: SMSEnvNumbers
    def __init__(self, id: _Optional[str] = ..., template_name: _Optional[str] = ..., template_text: _Optional[str] = ..., created_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., created_by: _Optional[str] = ..., updated_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., updated_by: _Optional[str] = ..., sms_numbers: _Optional[_Union[SMSEnvNumbers, _Mapping]] = ...) -> None: ...

class FunctionReference(_message.Message):
    __slots__ = ("function_id", "resource_id")
    FUNCTION_ID_FIELD_NUMBER: _ClassVar[int]
    RESOURCE_ID_FIELD_NUMBER: _ClassVar[int]
    function_id: str
    resource_id: str
    def __init__(self, function_id: _Optional[str] = ..., resource_id: _Optional[str] = ...) -> None: ...

class StepLayout(_message.Message):
    __slots__ = ("x", "y")
    X_FIELD_NUMBER: _ClassVar[int]
    Y_FIELD_NUMBER: _ClassVar[int]
    x: float
    y: float
    def __init__(self, x: _Optional[float] = ..., y: _Optional[float] = ...) -> None: ...

class FlowStep(_message.Message):
    __slots__ = ("name", "content", "functions_referenced", "layout", "asr_biasing_config", "dtmf_config", "initial_timeout")
    NAME_FIELD_NUMBER: _ClassVar[int]
    CONTENT_FIELD_NUMBER: _ClassVar[int]
    FUNCTIONS_REFERENCED_FIELD_NUMBER: _ClassVar[int]
    LAYOUT_FIELD_NUMBER: _ClassVar[int]
    ASR_BIASING_CONFIG_FIELD_NUMBER: _ClassVar[int]
    DTMF_CONFIG_FIELD_NUMBER: _ClassVar[int]
    INITIAL_TIMEOUT_FIELD_NUMBER: _ClassVar[int]
    name: str
    content: str
    functions_referenced: _containers.RepeatedCompositeFieldContainer[FunctionReference]
    layout: StepLayout
    asr_biasing_config: StepAsrBiasingConfig
    dtmf_config: StepDTMFConfig
    initial_timeout: _duration_pb2.Duration
    def __init__(self, name: _Optional[str] = ..., content: _Optional[str] = ..., functions_referenced: _Optional[_Iterable[_Union[FunctionReference, _Mapping]]] = ..., layout: _Optional[_Union[StepLayout, _Mapping]] = ..., asr_biasing_config: _Optional[_Union[StepAsrBiasingConfig, _Mapping]] = ..., dtmf_config: _Optional[_Union[StepDTMFConfig, _Mapping]] = ..., initial_timeout: _Optional[_Union[_duration_pb2.Duration, _Mapping]] = ...) -> None: ...

class FunctionStep(_message.Message):
    __slots__ = ("name", "function_reference")
    NAME_FIELD_NUMBER: _ClassVar[int]
    FUNCTION_REFERENCE_FIELD_NUMBER: _ClassVar[int]
    name: str
    function_reference: FunctionReference
    def __init__(self, name: _Optional[str] = ..., function_reference: _Optional[_Union[FunctionReference, _Mapping]] = ...) -> None: ...

class FlowStartStep(_message.Message):
    __slots__ = ("advanced_step", "no_code_step", "function_step")
    ADVANCED_STEP_FIELD_NUMBER: _ClassVar[int]
    NO_CODE_STEP_FIELD_NUMBER: _ClassVar[int]
    FUNCTION_STEP_FIELD_NUMBER: _ClassVar[int]
    advanced_step: FlowStep
    no_code_step: NoCodeStep
    function_step: FunctionStep
    def __init__(self, advanced_step: _Optional[_Union[FlowStep, _Mapping]] = ..., no_code_step: _Optional[_Union[NoCodeStep, _Mapping]] = ..., function_step: _Optional[_Union[FunctionStep, _Mapping]] = ...) -> None: ...

class Step(_message.Message):
    __slots__ = ("advanced_step", "no_code_step", "function_step")
    ADVANCED_STEP_FIELD_NUMBER: _ClassVar[int]
    NO_CODE_STEP_FIELD_NUMBER: _ClassVar[int]
    FUNCTION_STEP_FIELD_NUMBER: _ClassVar[int]
    advanced_step: FlowStep
    no_code_step: NoCodeStep
    function_step: FunctionStep
    def __init__(self, advanced_step: _Optional[_Union[FlowStep, _Mapping]] = ..., no_code_step: _Optional[_Union[NoCodeStep, _Mapping]] = ..., function_step: _Optional[_Union[FunctionStep, _Mapping]] = ...) -> None: ...

class NoCodeStepConditionDetails(_message.Message):
    __slots__ = ("label", "description", "required_entities")
    LABEL_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    REQUIRED_ENTITIES_FIELD_NUMBER: _ClassVar[int]
    label: str
    description: str
    required_entities: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, label: _Optional[str] = ..., description: _Optional[str] = ..., required_entities: _Optional[_Iterable[str]] = ...) -> None: ...

class NoCodeStepReferences(_message.Message):
    __slots__ = ("details",)
    DETAILS_FIELD_NUMBER: _ClassVar[int]
    details: NoCodeStepConditionDetails
    def __init__(self, details: _Optional[_Union[NoCodeStepConditionDetails, _Mapping]] = ...) -> None: ...

class ExitFlowCondition(_message.Message):
    __slots__ = ("details",)
    DETAILS_FIELD_NUMBER: _ClassVar[int]
    details: NoCodeStepConditionDetails
    def __init__(self, details: _Optional[_Union[NoCodeStepConditionDetails, _Mapping]] = ...) -> None: ...

class FunctionStepConditionDetails(_message.Message):
    __slots__ = ("label", "description")
    LABEL_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    label: str
    description: str
    def __init__(self, label: _Optional[str] = ..., description: _Optional[str] = ...) -> None: ...

class FlowStepCondition(_message.Message):
    __slots__ = ("details", "child_step_name")
    DETAILS_FIELD_NUMBER: _ClassVar[int]
    CHILD_STEP_NAME_FIELD_NUMBER: _ClassVar[int]
    details: NoCodeStepConditionDetails
    child_step_name: str
    def __init__(self, details: _Optional[_Union[NoCodeStepConditionDetails, _Mapping]] = ..., child_step_name: _Optional[str] = ...) -> None: ...

class NoCodeStepCondition(_message.Message):
    __slots__ = ("details", "child_step_name")
    DETAILS_FIELD_NUMBER: _ClassVar[int]
    CHILD_STEP_NAME_FIELD_NUMBER: _ClassVar[int]
    details: NoCodeStepConditionDetails
    child_step_name: str
    def __init__(self, details: _Optional[_Union[NoCodeStepConditionDetails, _Mapping]] = ..., child_step_name: _Optional[str] = ...) -> None: ...

class FunctionStepCondition(_message.Message):
    __slots__ = ("details", "child_step_name")
    DETAILS_FIELD_NUMBER: _ClassVar[int]
    CHILD_STEP_NAME_FIELD_NUMBER: _ClassVar[int]
    details: FunctionStepConditionDetails
    child_step_name: str
    def __init__(self, details: _Optional[_Union[FunctionStepConditionDetails, _Mapping]] = ..., child_step_name: _Optional[str] = ...) -> None: ...

class Condition(_message.Message):
    __slots__ = ("exit_flow_condition", "step_condition", "no_code_step_condition", "function_step_condition")
    EXIT_FLOW_CONDITION_FIELD_NUMBER: _ClassVar[int]
    STEP_CONDITION_FIELD_NUMBER: _ClassVar[int]
    NO_CODE_STEP_CONDITION_FIELD_NUMBER: _ClassVar[int]
    FUNCTION_STEP_CONDITION_FIELD_NUMBER: _ClassVar[int]
    exit_flow_condition: ExitFlowCondition
    step_condition: FlowStepCondition
    no_code_step_condition: NoCodeStepCondition
    function_step_condition: FunctionStepCondition
    def __init__(self, exit_flow_condition: _Optional[_Union[ExitFlowCondition, _Mapping]] = ..., step_condition: _Optional[_Union[FlowStepCondition, _Mapping]] = ..., no_code_step_condition: _Optional[_Union[NoCodeStepCondition, _Mapping]] = ..., function_step_condition: _Optional[_Union[FunctionStepCondition, _Mapping]] = ...) -> None: ...

class NoCodeStep(_message.Message):
    __slots__ = ("name", "prompt", "entity_references", "conditions")
    NAME_FIELD_NUMBER: _ClassVar[int]
    PROMPT_FIELD_NUMBER: _ClassVar[int]
    ENTITY_REFERENCES_FIELD_NUMBER: _ClassVar[int]
    CONDITIONS_FIELD_NUMBER: _ClassVar[int]
    name: str
    prompt: str
    entity_references: _containers.RepeatedScalarFieldContainer[str]
    conditions: _containers.RepeatedCompositeFieldContainer[Condition]
    def __init__(self, name: _Optional[str] = ..., prompt: _Optional[str] = ..., entity_references: _Optional[_Iterable[str]] = ..., conditions: _Optional[_Iterable[_Union[Condition, _Mapping]]] = ...) -> None: ...

class StepAsrBiasingConfig(_message.Message):
    __slots__ = ("alphanumeric", "name_spelling", "numeric", "party_size", "precise_date", "relative_date", "single_number", "time", "yes_no", "custom_keywords", "address", "is_enabled")
    ALPHANUMERIC_FIELD_NUMBER: _ClassVar[int]
    NAME_SPELLING_FIELD_NUMBER: _ClassVar[int]
    NUMERIC_FIELD_NUMBER: _ClassVar[int]
    PARTY_SIZE_FIELD_NUMBER: _ClassVar[int]
    PRECISE_DATE_FIELD_NUMBER: _ClassVar[int]
    RELATIVE_DATE_FIELD_NUMBER: _ClassVar[int]
    SINGLE_NUMBER_FIELD_NUMBER: _ClassVar[int]
    TIME_FIELD_NUMBER: _ClassVar[int]
    YES_NO_FIELD_NUMBER: _ClassVar[int]
    CUSTOM_KEYWORDS_FIELD_NUMBER: _ClassVar[int]
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    IS_ENABLED_FIELD_NUMBER: _ClassVar[int]
    alphanumeric: bool
    name_spelling: bool
    numeric: bool
    party_size: bool
    precise_date: bool
    relative_date: bool
    single_number: bool
    time: bool
    yes_no: bool
    custom_keywords: _containers.RepeatedScalarFieldContainer[str]
    address: bool
    is_enabled: bool
    def __init__(self, alphanumeric: bool = ..., name_spelling: bool = ..., numeric: bool = ..., party_size: bool = ..., precise_date: bool = ..., relative_date: bool = ..., single_number: bool = ..., time: bool = ..., yes_no: bool = ..., custom_keywords: _Optional[_Iterable[str]] = ..., address: bool = ..., is_enabled: bool = ...) -> None: ...

class StepDTMFConfig(_message.Message):
    __slots__ = ("is_enabled", "inter_digit_timeout", "max_digits", "end_key", "collect_while_agent_speaking", "is_pii")
    IS_ENABLED_FIELD_NUMBER: _ClassVar[int]
    INTER_DIGIT_TIMEOUT_FIELD_NUMBER: _ClassVar[int]
    MAX_DIGITS_FIELD_NUMBER: _ClassVar[int]
    END_KEY_FIELD_NUMBER: _ClassVar[int]
    COLLECT_WHILE_AGENT_SPEAKING_FIELD_NUMBER: _ClassVar[int]
    IS_PII_FIELD_NUMBER: _ClassVar[int]
    is_enabled: bool
    inter_digit_timeout: _duration_pb2.Duration
    max_digits: int
    end_key: str
    collect_while_agent_speaking: bool
    is_pii: bool
    def __init__(self, is_enabled: bool = ..., inter_digit_timeout: _Optional[_Union[_duration_pb2.Duration, _Mapping]] = ..., max_digits: _Optional[int] = ..., end_key: _Optional[str] = ..., collect_while_agent_speaking: bool = ..., is_pii: bool = ...) -> None: ...

class Flow(_message.Message):
    __slots__ = ("id", "name", "description", "start_step", "steps", "created_at", "created_by", "updated_at", "updated_by", "no_code_start_step", "no_code_steps", "flow_start_step", "flow_steps")
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    START_STEP_FIELD_NUMBER: _ClassVar[int]
    STEPS_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    CREATED_BY_FIELD_NUMBER: _ClassVar[int]
    UPDATED_AT_FIELD_NUMBER: _ClassVar[int]
    UPDATED_BY_FIELD_NUMBER: _ClassVar[int]
    NO_CODE_START_STEP_FIELD_NUMBER: _ClassVar[int]
    NO_CODE_STEPS_FIELD_NUMBER: _ClassVar[int]
    FLOW_START_STEP_FIELD_NUMBER: _ClassVar[int]
    FLOW_STEPS_FIELD_NUMBER: _ClassVar[int]
    id: str
    name: str
    description: str
    start_step: FlowStep
    steps: _containers.RepeatedCompositeFieldContainer[FlowStep]
    created_at: _timestamp_pb2.Timestamp
    created_by: str
    updated_at: _timestamp_pb2.Timestamp
    updated_by: str
    no_code_start_step: NoCodeStep
    no_code_steps: _containers.RepeatedCompositeFieldContainer[NoCodeStep]
    flow_start_step: FlowStartStep
    flow_steps: _containers.RepeatedCompositeFieldContainer[Step]
    def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ..., description: _Optional[str] = ..., start_step: _Optional[_Union[FlowStep, _Mapping]] = ..., steps: _Optional[_Iterable[_Union[FlowStep, _Mapping]]] = ..., created_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., created_by: _Optional[str] = ..., updated_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., updated_by: _Optional[str] = ..., no_code_start_step: _Optional[_Union[NoCodeStep, _Mapping]] = ..., no_code_steps: _Optional[_Iterable[_Union[NoCodeStep, _Mapping]]] = ..., flow_start_step: _Optional[_Union[FlowStartStep, _Mapping]] = ..., flow_steps: _Optional[_Iterable[_Union[Step, _Mapping]]] = ...) -> None: ...

class Flows(_message.Message):
    __slots__ = ("flow_list",)
    FLOW_LIST_FIELD_NUMBER: _ClassVar[int]
    flow_list: _containers.RepeatedCompositeFieldContainer[Flow]
    def __init__(self, flow_list: _Optional[_Iterable[_Union[Flow, _Mapping]]] = ...) -> None: ...

class AudioToPlay(_message.Message):
    __slots__ = ("s3_path", "original_filename")
    S3_PATH_FIELD_NUMBER: _ClassVar[int]
    ORIGINAL_FILENAME_FIELD_NUMBER: _ClassVar[int]
    s3_path: str
    original_filename: str
    def __init__(self, s3_path: _Optional[str] = ..., original_filename: _Optional[str] = ...) -> None: ...

class IntroMessage(_message.Message):
    __slots__ = ("disclaimer_enabled", "disclaimer_message", "disclaimer_voice", "disclaimer_voice_id", "disclaimer_voice_tuning_settings", "ringing_tone", "language_code")
    DISCLAIMER_ENABLED_FIELD_NUMBER: _ClassVar[int]
    DISCLAIMER_MESSAGE_FIELD_NUMBER: _ClassVar[int]
    DISCLAIMER_VOICE_FIELD_NUMBER: _ClassVar[int]
    DISCLAIMER_VOICE_ID_FIELD_NUMBER: _ClassVar[int]
    DISCLAIMER_VOICE_TUNING_SETTINGS_FIELD_NUMBER: _ClassVar[int]
    RINGING_TONE_FIELD_NUMBER: _ClassVar[int]
    LANGUAGE_CODE_FIELD_NUMBER: _ClassVar[int]
    disclaimer_enabled: bool
    disclaimer_message: str
    disclaimer_voice: Voice
    disclaimer_voice_id: str
    disclaimer_voice_tuning_settings: _containers.RepeatedCompositeFieldContainer[VoiceTuningSettings]
    ringing_tone: AudioToPlay
    language_code: str
    def __init__(self, disclaimer_enabled: bool = ..., disclaimer_message: _Optional[str] = ..., disclaimer_voice: _Optional[_Union[Voice, _Mapping]] = ..., disclaimer_voice_id: _Optional[str] = ..., disclaimer_voice_tuning_settings: _Optional[_Iterable[_Union[VoiceTuningSettings, _Mapping]]] = ..., ringing_tone: _Optional[_Union[AudioToPlay, _Mapping]] = ..., language_code: _Optional[str] = ...) -> None: ...

class AzureContentFilterCategory(_message.Message):
    __slots__ = ("is_active", "precision")
    IS_ACTIVE_FIELD_NUMBER: _ClassVar[int]
    PRECISION_FIELD_NUMBER: _ClassVar[int]
    is_active: bool
    precision: str
    def __init__(self, is_active: bool = ..., precision: _Optional[str] = ...) -> None: ...

class AzureContentFilter(_message.Message):
    __slots__ = ("violence", "hate", "sexual", "self_harm")
    VIOLENCE_FIELD_NUMBER: _ClassVar[int]
    HATE_FIELD_NUMBER: _ClassVar[int]
    SEXUAL_FIELD_NUMBER: _ClassVar[int]
    SELF_HARM_FIELD_NUMBER: _ClassVar[int]
    violence: AzureContentFilterCategory
    hate: AzureContentFilterCategory
    sexual: AzureContentFilterCategory
    self_harm: AzureContentFilterCategory
    def __init__(self, violence: _Optional[_Union[AzureContentFilterCategory, _Mapping]] = ..., hate: _Optional[_Union[AzureContentFilterCategory, _Mapping]] = ..., sexual: _Optional[_Union[AzureContentFilterCategory, _Mapping]] = ..., self_harm: _Optional[_Union[AzureContentFilterCategory, _Mapping]] = ...) -> None: ...

class ContentFilter(_message.Message):
    __slots__ = ("type", "azure_config", "disabled")
    TYPE_FIELD_NUMBER: _ClassVar[int]
    AZURE_CONFIG_FIELD_NUMBER: _ClassVar[int]
    DISABLED_FIELD_NUMBER: _ClassVar[int]
    type: str
    azure_config: AzureContentFilter
    disabled: bool
    def __init__(self, type: _Optional[str] = ..., azure_config: _Optional[_Union[AzureContentFilter, _Mapping]] = ..., disabled: bool = ...) -> None: ...

class LatencyConfig(_message.Message):
    __slots__ = ("interaction_type",)
    INTERACTION_TYPE_FIELD_NUMBER: _ClassVar[int]
    interaction_type: str
    def __init__(self, interaction_type: _Optional[str] = ...) -> None: ...

class BargeInConfig(_message.Message):
    __slots__ = ("enabled",)
    ENABLED_FIELD_NUMBER: _ClassVar[int]
    enabled: bool
    def __init__(self, enabled: bool = ...) -> None: ...

class StopKeywords(_message.Message):
    __slots__ = ("id", "created_by", "created_at", "updated_by", "updated_at", "title", "description", "regular_expressions", "say_phrase", "function_id", "language_code")
    ID_FIELD_NUMBER: _ClassVar[int]
    CREATED_BY_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    UPDATED_BY_FIELD_NUMBER: _ClassVar[int]
    UPDATED_AT_FIELD_NUMBER: _ClassVar[int]
    TITLE_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    REGULAR_EXPRESSIONS_FIELD_NUMBER: _ClassVar[int]
    SAY_PHRASE_FIELD_NUMBER: _ClassVar[int]
    FUNCTION_ID_FIELD_NUMBER: _ClassVar[int]
    LANGUAGE_CODE_FIELD_NUMBER: _ClassVar[int]
    id: str
    created_by: str
    created_at: _timestamp_pb2.Timestamp
    updated_by: str
    updated_at: _timestamp_pb2.Timestamp
    title: str
    description: str
    regular_expressions: _containers.RepeatedScalarFieldContainer[str]
    say_phrase: bool
    function_id: str
    language_code: str
    def __init__(self, id: _Optional[str] = ..., created_by: _Optional[str] = ..., created_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., updated_by: _Optional[str] = ..., updated_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., title: _Optional[str] = ..., description: _Optional[str] = ..., regular_expressions: _Optional[_Iterable[str]] = ..., say_phrase: bool = ..., function_id: _Optional[str] = ..., language_code: _Optional[str] = ...) -> None: ...

class AsrKeyphrase(_message.Message):
    __slots__ = ("keyphrase", "level")
    KEYPHRASE_FIELD_NUMBER: _ClassVar[int]
    LEVEL_FIELD_NUMBER: _ClassVar[int]
    keyphrase: str
    level: str
    def __init__(self, keyphrase: _Optional[str] = ..., level: _Optional[str] = ...) -> None: ...

class Variant(_message.Message):
    __slots__ = ("id", "name", "created_by", "created_at", "updated_by", "updated_at", "is_default")
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    CREATED_BY_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    UPDATED_BY_FIELD_NUMBER: _ClassVar[int]
    UPDATED_AT_FIELD_NUMBER: _ClassVar[int]
    IS_DEFAULT_FIELD_NUMBER: _ClassVar[int]
    id: str
    name: str
    created_by: str
    created_at: _timestamp_pb2.Timestamp
    updated_by: str
    updated_at: _timestamp_pb2.Timestamp
    is_default: bool
    def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ..., created_by: _Optional[str] = ..., created_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., updated_by: _Optional[str] = ..., updated_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., is_default: bool = ...) -> None: ...

class VariantAttribute(_message.Message):
    __slots__ = ("id", "name", "attribute_type", "created_by", "created_at", "updated_by", "updated_at", "values")
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    ATTRIBUTE_TYPE_FIELD_NUMBER: _ClassVar[int]
    CREATED_BY_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    UPDATED_BY_FIELD_NUMBER: _ClassVar[int]
    UPDATED_AT_FIELD_NUMBER: _ClassVar[int]
    VALUES_FIELD_NUMBER: _ClassVar[int]
    id: str
    name: str
    attribute_type: str
    created_by: str
    created_at: _timestamp_pb2.Timestamp
    updated_by: str
    updated_at: _timestamp_pb2.Timestamp
    values: _struct_pb2.Struct
    def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ..., attribute_type: _Optional[str] = ..., created_by: _Optional[str] = ..., created_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., updated_by: _Optional[str] = ..., updated_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., values: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ...) -> None: ...

class AsrCorrection(_message.Message):
    __slots__ = ("id", "name", "description", "regular_expressions")
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    REGULAR_EXPRESSIONS_FIELD_NUMBER: _ClassVar[int]
    id: str
    name: str
    description: str
    regular_expressions: _containers.RepeatedCompositeFieldContainer[AsrCorrectionRegularExpressions]
    def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ..., description: _Optional[str] = ..., regular_expressions: _Optional[_Iterable[_Union[AsrCorrectionRegularExpressions, _Mapping]]] = ...) -> None: ...

class AsrCorrectionRegularExpressions(_message.Message):
    __slots__ = ("regular_expression", "replacement", "replacement_type")
    REGULAR_EXPRESSION_FIELD_NUMBER: _ClassVar[int]
    REPLACEMENT_FIELD_NUMBER: _ClassVar[int]
    REPLACEMENT_TYPE_FIELD_NUMBER: _ClassVar[int]
    regular_expression: str
    replacement: str
    replacement_type: str
    def __init__(self, regular_expression: _Optional[str] = ..., replacement: _Optional[str] = ..., replacement_type: _Optional[str] = ...) -> None: ...

class ApiIntegrations(_message.Message):
    __slots__ = ("api_integrations",)
    API_INTEGRATIONS_FIELD_NUMBER: _ClassVar[int]
    api_integrations: _containers.RepeatedCompositeFieldContainer[ApiIntegration]
    def __init__(self, api_integrations: _Optional[_Iterable[_Union[ApiIntegration, _Mapping]]] = ...) -> None: ...

class ApiIntegration(_message.Message):
    __slots__ = ("id", "name", "description", "environments", "operations")
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    ENVIRONMENTS_FIELD_NUMBER: _ClassVar[int]
    OPERATIONS_FIELD_NUMBER: _ClassVar[int]
    id: str
    name: str
    description: str
    environments: Environments
    operations: _containers.RepeatedCompositeFieldContainer[ApiIntegrationOperation]
    def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ..., description: _Optional[str] = ..., environments: _Optional[_Union[Environments, _Mapping]] = ..., operations: _Optional[_Iterable[_Union[ApiIntegrationOperation, _Mapping]]] = ...) -> None: ...

class Environments(_message.Message):
    __slots__ = ("sandbox", "pre_release", "live")
    SANDBOX_FIELD_NUMBER: _ClassVar[int]
    PRE_RELEASE_FIELD_NUMBER: _ClassVar[int]
    LIVE_FIELD_NUMBER: _ClassVar[int]
    sandbox: ApiIntegrationConfig
    pre_release: ApiIntegrationConfig
    live: ApiIntegrationConfig
    def __init__(self, sandbox: _Optional[_Union[ApiIntegrationConfig, _Mapping]] = ..., pre_release: _Optional[_Union[ApiIntegrationConfig, _Mapping]] = ..., live: _Optional[_Union[ApiIntegrationConfig, _Mapping]] = ...) -> None: ...

class ApiIntegrationConfig(_message.Message):
    __slots__ = ("base_url", "auth_type")
    BASE_URL_FIELD_NUMBER: _ClassVar[int]
    AUTH_TYPE_FIELD_NUMBER: _ClassVar[int]
    base_url: str
    auth_type: str
    def __init__(self, base_url: _Optional[str] = ..., auth_type: _Optional[str] = ...) -> None: ...

class ApiIntegrationOperation(_message.Message):
    __slots__ = ("id", "name", "method", "resource")
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    METHOD_FIELD_NUMBER: _ClassVar[int]
    RESOURCE_FIELD_NUMBER: _ClassVar[int]
    id: str
    name: str
    method: str
    resource: str
    def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ..., method: _Optional[str] = ..., resource: _Optional[str] = ...) -> None: ...

class Language(_message.Message):
    __slots__ = ("code",)
    CODE_FIELD_NUMBER: _ClassVar[int]
    code: str
    def __init__(self, code: _Optional[str] = ...) -> None: ...

class Languages(_message.Message):
    __slots__ = ("default_language", "additional_languages")
    DEFAULT_LANGUAGE_FIELD_NUMBER: _ClassVar[int]
    ADDITIONAL_LANGUAGES_FIELD_NUMBER: _ClassVar[int]
    default_language: Language
    additional_languages: _containers.RepeatedCompositeFieldContainer[Language]
    def __init__(self, default_language: _Optional[_Union[Language, _Mapping]] = ..., additional_languages: _Optional[_Iterable[_Union[Language, _Mapping]]] = ...) -> None: ...

class LanguageBehavior(_message.Message):
    __slots__ = ("behavior_prompt", "language_code")
    BEHAVIOR_PROMPT_FIELD_NUMBER: _ClassVar[int]
    LANGUAGE_CODE_FIELD_NUMBER: _ClassVar[int]
    behavior_prompt: str
    language_code: str
    def __init__(self, behavior_prompt: _Optional[str] = ..., language_code: _Optional[str] = ...) -> None: ...

class Greeting(_message.Message):
    __slots__ = ("welcome_message", "language_code")
    WELCOME_MESSAGE_FIELD_NUMBER: _ClassVar[int]
    LANGUAGE_CODE_FIELD_NUMBER: _ClassVar[int]
    welcome_message: str
    language_code: str
    def __init__(self, welcome_message: _Optional[str] = ..., language_code: _Optional[str] = ...) -> None: ...

class MultilingualAgentSettings(_message.Message):
    __slots__ = ("language_behaviors", "greetings")
    class LanguageBehaviorsEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: LanguageBehavior
        def __init__(self, key: _Optional[str] = ..., value: _Optional[_Union[LanguageBehavior, _Mapping]] = ...) -> None: ...
    class GreetingsEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: Greeting
        def __init__(self, key: _Optional[str] = ..., value: _Optional[_Union[Greeting, _Mapping]] = ...) -> None: ...
    LANGUAGE_BEHAVIORS_FIELD_NUMBER: _ClassVar[int]
    GREETINGS_FIELD_NUMBER: _ClassVar[int]
    language_behaviors: _containers.MessageMap[str, LanguageBehavior]
    greetings: _containers.MessageMap[str, Greeting]
    def __init__(self, language_behaviors: _Optional[_Mapping[str, LanguageBehavior]] = ..., greetings: _Optional[_Mapping[str, Greeting]] = ...) -> None: ...

class LocalizedText(_message.Message):
    __slots__ = ("text",)
    TEXT_FIELD_NUMBER: _ClassVar[int]
    text: str
    def __init__(self, text: _Optional[str] = ...) -> None: ...

class TranslationEntry(_message.Message):
    __slots__ = ("language_key", "translations", "id")
    class TranslationsEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: LocalizedText
        def __init__(self, key: _Optional[str] = ..., value: _Optional[_Union[LocalizedText, _Mapping]] = ...) -> None: ...
    LANGUAGE_KEY_FIELD_NUMBER: _ClassVar[int]
    TRANSLATIONS_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    language_key: str
    translations: _containers.MessageMap[str, LocalizedText]
    id: str
    def __init__(self, language_key: _Optional[str] = ..., translations: _Optional[_Mapping[str, LocalizedText]] = ..., id: _Optional[str] = ...) -> None: ...

class MultilingualTranslations(_message.Message):
    __slots__ = ("translations",)
    TRANSLATIONS_FIELD_NUMBER: _ClassVar[int]
    translations: _containers.RepeatedCompositeFieldContainer[TranslationEntry]
    def __init__(self, translations: _Optional[_Iterable[_Union[TranslationEntry, _Mapping]]] = ...) -> None: ...

class StylePrompt(_message.Message):
    __slots__ = ("prompt",)
    PROMPT_FIELD_NUMBER: _ClassVar[int]
    prompt: str
    def __init__(self, prompt: _Optional[str] = ...) -> None: ...

class ChannelConfig(_message.Message):
    __slots__ = ("model_id", "style_prompt", "greeting", "safety_filters")
    MODEL_ID_FIELD_NUMBER: _ClassVar[int]
    STYLE_PROMPT_FIELD_NUMBER: _ClassVar[int]
    GREETING_FIELD_NUMBER: _ClassVar[int]
    SAFETY_FILTERS_FIELD_NUMBER: _ClassVar[int]
    model_id: str
    style_prompt: StylePrompt
    greeting: Greeting
    safety_filters: ContentFilter
    def __init__(self, model_id: _Optional[str] = ..., style_prompt: _Optional[_Union[StylePrompt, _Mapping]] = ..., greeting: _Optional[_Union[Greeting, _Mapping]] = ..., safety_filters: _Optional[_Union[ContentFilter, _Mapping]] = ...) -> None: ...

class VoiceChannel(_message.Message):
    __slots__ = ("enabled", "config", "barge_in_config", "latency_config", "disclaimer")
    ENABLED_FIELD_NUMBER: _ClassVar[int]
    CONFIG_FIELD_NUMBER: _ClassVar[int]
    BARGE_IN_CONFIG_FIELD_NUMBER: _ClassVar[int]
    LATENCY_CONFIG_FIELD_NUMBER: _ClassVar[int]
    DISCLAIMER_FIELD_NUMBER: _ClassVar[int]
    enabled: bool
    config: ChannelConfig
    barge_in_config: BargeInConfig
    latency_config: LatencyConfig
    disclaimer: IntroMessage
    def __init__(self, enabled: bool = ..., config: _Optional[_Union[ChannelConfig, _Mapping]] = ..., barge_in_config: _Optional[_Union[BargeInConfig, _Mapping]] = ..., latency_config: _Optional[_Union[LatencyConfig, _Mapping]] = ..., disclaimer: _Optional[_Union[IntroMessage, _Mapping]] = ...) -> None: ...

class WebChatChannel(_message.Message):
    __slots__ = ("enabled", "config")
    ENABLED_FIELD_NUMBER: _ClassVar[int]
    CONFIG_FIELD_NUMBER: _ClassVar[int]
    enabled: bool
    config: ChannelConfig
    def __init__(self, enabled: bool = ..., config: _Optional[_Union[ChannelConfig, _Mapping]] = ...) -> None: ...

class Channels(_message.Message):
    __slots__ = ("voice", "web_chat")
    VOICE_FIELD_NUMBER: _ClassVar[int]
    WEB_CHAT_FIELD_NUMBER: _ClassVar[int]
    voice: VoiceChannel
    web_chat: WebChatChannel
    def __init__(self, voice: _Optional[_Union[VoiceChannel, _Mapping]] = ..., web_chat: _Optional[_Union[WebChatChannel, _Mapping]] = ...) -> None: ...



from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ApiIntegrations(_message.Message):
    __slots__ = ("api_integrations",)
    API_INTEGRATIONS_FIELD_NUMBER: _ClassVar[int]
    api_integrations: _containers.RepeatedCompositeFieldContainer[ApiIntegration]
    def __init__(self, api_integrations: _Optional[_Iterable[_Union[ApiIntegration, _Mapping]]] = ...) -> None: ...

class ApiIntegration(_message.Message):
    __slots__ = ("id", "name", "description", "environments", "created_at", "created_by", "updated_at", "updated_by", "operations")
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    ENVIRONMENTS_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    CREATED_BY_FIELD_NUMBER: _ClassVar[int]
    UPDATED_AT_FIELD_NUMBER: _ClassVar[int]
    UPDATED_BY_FIELD_NUMBER: _ClassVar[int]
    OPERATIONS_FIELD_NUMBER: _ClassVar[int]
    id: str
    name: str
    description: str
    environments: Environments
    created_at: _timestamp_pb2.Timestamp
    created_by: str
    updated_at: _timestamp_pb2.Timestamp
    updated_by: str
    operations: _containers.RepeatedCompositeFieldContainer[ApiIntegrationOperation]
    def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ..., description: _Optional[str] = ..., environments: _Optional[_Union[Environments, _Mapping]] = ..., created_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., created_by: _Optional[str] = ..., updated_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., updated_by: _Optional[str] = ..., operations: _Optional[_Iterable[_Union[ApiIntegrationOperation, _Mapping]]] = ...) -> None: ...

class Environments(_message.Message):
    __slots__ = ("sandbox", "pre_release", "live")
    SANDBOX_FIELD_NUMBER: _ClassVar[int]
    PRE_RELEASE_FIELD_NUMBER: _ClassVar[int]
    LIVE_FIELD_NUMBER: _ClassVar[int]
    sandbox: ApiIntegrationConfig
    pre_release: ApiIntegrationConfig
    live: ApiIntegrationConfig
    def __init__(self, sandbox: _Optional[_Union[ApiIntegrationConfig, _Mapping]] = ..., pre_release: _Optional[_Union[ApiIntegrationConfig, _Mapping]] = ..., live: _Optional[_Union[ApiIntegrationConfig, _Mapping]] = ...) -> None: ...

class ApiIntegrationConfig(_message.Message):
    __slots__ = ("base_url", "auth_type")
    BASE_URL_FIELD_NUMBER: _ClassVar[int]
    AUTH_TYPE_FIELD_NUMBER: _ClassVar[int]
    base_url: str
    auth_type: str
    def __init__(self, base_url: _Optional[str] = ..., auth_type: _Optional[str] = ...) -> None: ...

class ApiIntegrationOperation(_message.Message):
    __slots__ = ("id", "name", "method", "resource", "created_at", "created_by", "updated_at", "updated_by")
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    METHOD_FIELD_NUMBER: _ClassVar[int]
    RESOURCE_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    CREATED_BY_FIELD_NUMBER: _ClassVar[int]
    UPDATED_AT_FIELD_NUMBER: _ClassVar[int]
    UPDATED_BY_FIELD_NUMBER: _ClassVar[int]
    id: str
    name: str
    method: str
    resource: str
    created_at: _timestamp_pb2.Timestamp
    created_by: str
    updated_at: _timestamp_pb2.Timestamp
    updated_by: str
    def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ..., method: _Optional[str] = ..., resource: _Optional[str] = ..., created_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., created_by: _Optional[str] = ..., updated_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., updated_by: _Optional[str] = ...) -> None: ...

class ApiIntegration_Create(_message.Message):
    __slots__ = ("id", "name", "description", "environments")
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    ENVIRONMENTS_FIELD_NUMBER: _ClassVar[int]
    id: str
    name: str
    description: str
    environments: Environments
    def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ..., description: _Optional[str] = ..., environments: _Optional[_Union[Environments, _Mapping]] = ...) -> None: ...

class ApiIntegration_Update(_message.Message):
    __slots__ = ("id", "name", "description")
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    id: str
    name: str
    description: str
    def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ..., description: _Optional[str] = ...) -> None: ...

class ApiIntegration_Delete(_message.Message):
    __slots__ = ("id",)
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class ApiIntegrationConfig_Update(_message.Message):
    __slots__ = ("id", "environment", "base_url", "auth_type")
    ID_FIELD_NUMBER: _ClassVar[int]
    ENVIRONMENT_FIELD_NUMBER: _ClassVar[int]
    BASE_URL_FIELD_NUMBER: _ClassVar[int]
    AUTH_TYPE_FIELD_NUMBER: _ClassVar[int]
    id: str
    environment: str
    base_url: str
    auth_type: str
    def __init__(self, id: _Optional[str] = ..., environment: _Optional[str] = ..., base_url: _Optional[str] = ..., auth_type: _Optional[str] = ...) -> None: ...

class ApiIntegrationOperation_Create(_message.Message):
    __slots__ = ("name", "method", "resource", "integration_id", "id")
    NAME_FIELD_NUMBER: _ClassVar[int]
    METHOD_FIELD_NUMBER: _ClassVar[int]
    RESOURCE_FIELD_NUMBER: _ClassVar[int]
    INTEGRATION_ID_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    name: str
    method: str
    resource: str
    integration_id: str
    id: str
    def __init__(self, name: _Optional[str] = ..., method: _Optional[str] = ..., resource: _Optional[str] = ..., integration_id: _Optional[str] = ..., id: _Optional[str] = ...) -> None: ...

class ApiIntegrationOperation_Update(_message.Message):
    __slots__ = ("id", "name", "method", "resource", "integration_id")
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    METHOD_FIELD_NUMBER: _ClassVar[int]
    RESOURCE_FIELD_NUMBER: _ClassVar[int]
    INTEGRATION_ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    name: str
    method: str
    resource: str
    integration_id: str
    def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ..., method: _Optional[str] = ..., resource: _Optional[str] = ..., integration_id: _Optional[str] = ...) -> None: ...

class ApiIntegrationOperation_Delete(_message.Message):
    __slots__ = ("id", "integration_id")
    ID_FIELD_NUMBER: _ClassVar[int]
    INTEGRATION_ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    integration_id: str
    def __init__(self, id: _Optional[str] = ..., integration_id: _Optional[str] = ...) -> None: ...



"""Handling and managing an Agent Studio Handoff

Copyright PolyAI Limited
"""

import os
from dataclasses import dataclass
from typing import ClassVar

import poly.resources.resource_utils as utils
from poly.handlers.protobuf.handoff_pb2 import (
    Handoff_Create,
    Handoff_Delete,
    Handoff_Update,
    SipByeHandoffConfig,
    SipConfig,
    SipHeader,
    SipHeaders,
    SipInviteHandoffConfig,
    SipReferHandoffConfig,
)
from poly.resources.resource import (
    MultiResourceYamlResource,
)

VALID_SIP_METHODS = ("invite", "refer", "bye")
VALID_ENCRYPTION = ("TLS/SRTP", "UDP/RTP")


@dataclass
class HandoffSipConfig:
    method: str
    phone_number: str = ""
    outbound_endpoint: str = ""
    outbound_encryption: str = ""

    def to_yaml_dict(self) -> dict:
        result = {"method": self.method}
        if self.method == "invite":
            result["phone_number"] = self.phone_number
            result["outbound_endpoint"] = self.outbound_endpoint
            result["outbound_encryption"] = self.outbound_encryption
        elif self.method == "refer":
            result["phone_number"] = self.phone_number
        return result

    def to_proto(self) -> SipConfig:
        if self.method == "invite":
            return SipConfig(
                invite=SipInviteHandoffConfig(
                    phone_number=self.phone_number,
                    outbound_endpoint=self.outbound_endpoint,
                    outbound_encryption=self.outbound_encryption,
                )
            )
        elif self.method == "refer":
            return SipConfig(
                refer=SipReferHandoffConfig(
                    phone_number=self.phone_number,
                )
            )
        return SipConfig(bye=SipByeHandoffConfig())


@dataclass
class Handoff(MultiResourceYamlResource):
    """Handoff resource for ADK."""

    description: str
    is_default: bool
    sip_config: HandoffSipConfig
    sip_headers: list[dict]
    top_level_name: ClassVar[str] = "handoffs"

    def __init__(
        self,
        *,
        resource_id: str,
        name: str,
        description: str = "",
        is_default: bool = False,
        sip_config: HandoffSipConfig | dict | None = None,
        sip_headers: list | None = None,
    ):
        self.resource_id = resource_id
        self.name = name
        self.description = description
        self.is_default = is_default

        if sip_config is None:
            sip_config = {}
        if isinstance(sip_config, dict):
            sip_config = HandoffSipConfig(
                method=sip_config.get("method", "bye"),
                phone_number=sip_config.get("phone_number", ""),
                outbound_endpoint=sip_config.get("outbound_endpoint", ""),
                outbound_encryption=sip_config.get("outbound_encryption", ""),
            )

        self.sip_config = sip_config
        self.sip_headers = sip_headers or []

    def to_yaml_dict(self) -> dict:
        return {
            "name": self.name,
            "description": self.description,
            "is_default": self.is_default,
            "sip_config": self.sip_config.to_yaml_dict(),
            "sip_headers": self.sip_headers,
        }

    @property
    def file_path(self) -> str:
        path_safe_name = utils.clean_name(self.name, lowercase=False)
        return os.path.join("config", "handoffs.yaml", self.top_level_name, path_safe_name)

    @staticmethod
    def get_resource_prefix(**kwargs) -> str:
        return "ho"

    @classmethod
    def from_yaml_dict(
        cls, yaml_dict: dict, resource_id: str, name: str = "", **kwargs
    ) -> "Handoff":
        return cls(
            resource_id=resource_id,
            name=name,
            description=yaml_dict.get("description", ""),
            is_default=yaml_dict.get("is_default", False),
            sip_config=yaml_dict.get("sip_config", {}),
            sip_headers=yaml_dict.get("sip_headers", []),
        )

    @property
    def command_type(self) -> str:
        return "handoff"

    @property
    def delete_command_type(self) -> str:
        return "handoff_delete"

    @property
    def create_command_type(self) -> str:
        return "handoff_create"

    @property
    def update_command_type(self) -> str:
        return "handoff_update"

    def _build_sip_headers_proto(self) -> SipHeaders:
        return SipHeaders(
            headers=[
                SipHeader(key=h["key"], value=h["value"]) for h in self.sip_headers if h.get("key")
            ]
        )

    def build_update_proto(self) -> Handoff_Update:
        return Handoff_Update(
            id=self.resource_id,
            name=self.name,
            description=self.description,
            sip_config=self.sip_config.to_proto(),
            sip_headers=self._build_sip_headers_proto(),
            active=True,
        )

    def build_delete_proto(self) -> Handoff_Delete:
        return Handoff_Delete(id=self.resource_id)

    def build_create_proto(self) -> Handoff_Create:
        return Handoff_Create(
            id=self.resource_id,
            name=self.name,
            description=self.description,
            sip_config=self.sip_config.to_proto(),
            sip_headers=self._build_sip_headers_proto(),
            active=True,
        )

    def validate(self, **kwargs) -> None:
        if not self.name:
            raise ValueError("Handoff name is required")
        if self.sip_config.method not in VALID_SIP_METHODS:
            raise ValueError(
                f"Invalid SIP method '{self.sip_config.method}'. "
                f"Must be one of: {', '.join(VALID_SIP_METHODS)}"
            )
        if (
            self.sip_config.method == "invite"
            and self.sip_config.outbound_encryption not in VALID_ENCRYPTION
        ):
            raise ValueError(
                f"Invalid encryption method '{self.sip_config.outbound_encryption}'. "
                f"Must be one of: {', '.join(VALID_ENCRYPTION)}"
            )

    @classmethod
    def validate_collection(
        cls,
        resources: dict[str, "Handoff"],
    ) -> None:
        default_names = [h.name for h in resources.values() if h.is_default]
        if len(default_names) != 1:
            raise ValueError(
                f"Multiple or zero default handoffs detected: {default_names}. "
                "One handoff must be set as default."
            )

    @staticmethod
    def discover_resources(base_path: str) -> list[str]:
        handoffs_path = os.path.join(base_path, "config", "handoffs.yaml")
        discovered_handoffs: list[str] = []

        if not os.path.exists(handoffs_path):
            return discovered_handoffs

        yaml_dict = Handoff._get_top_level_data(handoffs_path)
        handoffs: list[dict] = yaml_dict.get("handoffs", []) if yaml_dict else []

        for handoff in handoffs:
            name = handoff.get("name")
            if not name:
                continue
            path_safe_name = utils.clean_name(name, lowercase=False)
            discovered_handoffs.append(
                os.path.join(handoffs_path, Handoff.top_level_name, path_safe_name)
            )

        return discovered_handoffs
